@@ -1,77 +1,78 @@
-import subprocess
-from bs4 import BeautifulSoup
-import wget
+#Standart library imports
 import os
 import traceback
 import logging
 import time
 import stat
-import os
-
+import subprocess
+import re
+from pathlib import Path
+from typing import Any, Tuple
 import platform
 
-from typing import Tuple
-
-import sys
-import os.path
-sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__))))
+# Third party imports
+import wget
 
+# Local imports
 from _setting import setting
 
-from selenium import webdriver
-
-from selenium.common.exceptions import SessionNotCreatedException
-from selenium.common.exceptions import WebDriverException
-
 from util.extractor import Extractor
 from util.requests_getter import RequestsGetter
+
 from browsers._chromeBrowser import ChromeBrowser
 
-import pathlib
-
-import re
-
 class ChromeDriver():
+    """Class for working with Selenium chromedriver binary"""
 
     _tmp_folder_path = 'tmp'
-    
-    def __init__(self, path : str, **kwargs):
-        """Class for working with Selenium chromedriver binary
 
-        Args:
-            path (str)                          : Specified path which will used for downloading or updating Selenium chromedriver binary. Must be folder path.
-            upgrade (bool)                      : If true, it will overwrite existing driver in the folder. Defaults to False.
-            chmod (bool)                        : If true, it will make chromedriver binary executable. Defaults to True.
-            check_driver_is_up_to_date (bool)   : If true, it will check driver version before and after upgrade. Defaults to False.
-            filename (str)                      : Specific name for chromedriver. If given, it will replace name for chromedriver.
-            version (str)                       : Specific version for chromedriver. If given, it will downloads given version.
-            check_browser_is_up_to_date (bool)   : If true, it will check chrome browser version before chromedriver update/upgrade.
-        """
-        self.setting = setting
+    def __init__(self, **kwargs):
+
+        self.setting : Any = setting
+
+        self.path : str = str(kwargs.get('path'))
 
-        self.path : str = path
-                    
         self.upgrade : bool = bool(kwargs.get('upgrade'))
 
         self.chmod : bool = bool(kwargs.get('chmod'))
 
         self.check_driver_is_up_to_date : bool = bool(kwargs.get('check_driver_is_up_to_date'))
-        
-        specific_filename = str(kwargs.get('filename'))
-        self.filename = f"{specific_filename}.exe" if platform.system() == 'Windows' and specific_filename else\
-                        specific_filename
 
-        self.chromedriver_path : str =  self.path + self.setting['ChromeDriver']['LastReleasePlatform'] if not specific_filename else self.path + self.filename
+        self.specific_driver_name = ''
+        self.system_name = ''
+
+        specific_filename = str(kwargs.get('filename'))
+
+        specific_system = str(kwargs.get('system_name', ''))
+        specific_system = specific_system.replace('win64', 'win32').replace('linux32', 'linux64')
+
+        if specific_system:
+            self.system_name = f"chromedriver_{specific_system}.zip"
+
+            self.filename = f"{specific_filename}.exe" if 'win' in specific_system and specific_filename else\
+                            specific_filename
+
+            self.specific_driver_name =    "chromedriver.exe" if 'win' in specific_system else\
+                                                "chromedriver"
+
+            name = self.specific_driver_name
+
+        else:
+
+            self.filename = f"{specific_filename}.exe" if platform.system() == 'Windows' and specific_filename else\
+                            specific_filename
+
+            name = self.setting['ChromeDriver']['LastReleasePlatform']
+
+        self.chromedriver_path : str =  self.path + name if not specific_filename else self.path + self.filename
 
         self.version = str(kwargs.get('version'))
-        
-        self.check_browser_is_up_to_date = bool(kwargs.get('check_browser_is_up_to_date'))
 
         self.info_messages = bool(kwargs.get('info_messages'))
 
         self.extractor = Extractor
         self.requests_getter = RequestsGetter
-        self.chromebrowser = ChromeBrowser(path=self.path, check_browser_is_up_to_date=self.check_browser_is_up_to_date)
+        self.chromebrowser = ChromeBrowser(**kwargs)
 
     def main(self) -> Tuple[bool, str, str]:
         """Main function, checks for the latest version, downloads or updates chromedriver binary or
@@ -80,30 +81,28 @@ class ChromeDriver():
         Returns:
             Tuple of bool, str and str
 
-            result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
-            driver_path (str)       : Path where chromedriver was downloaded or updated.
-            
+            result_run (bool) : True if function passed correctly, False otherwise.
+            message_run (str) : Returns an error message if an error occurs in the function.
+            driver_path (str) : Path where chromedriver was downloaded or updated.
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
         result_run : bool = False
         message_run : str = ''
         driver_path : str = ''
-        
+
         try:
 
-            if self.check_browser_is_up_to_date:
-
-                result, message = self.chromebrowser.main()
-                if not result:
-                    logging.error(message)
-                    return result, message, driver_path
+            result, message = self.chromebrowser.main()
+            if not result:
+                logging.error(message)
+                return result, message, driver_path
 
             if not self.version:
 
-                #additional checking for equal versions
+                #additional checking for main versions to equal - for example, chromedriver version main is 90 and chrome browser is still 89
                 result, message, is_equal, latest_version_driver, latest_version_browser = self.__compare_latest_version_main_chromedriver_and_latest_version_main_chrome_browser()
                 if not result:
                     logging.error(message)
@@ -118,9 +117,10 @@ class ChromeDriver():
 
                 if not is_equal:
 
-                    message = (f' Problem with chromedriver latest_version_driver: {latest_version_driver} latest_version_browser: {latest_version_browser}\n'
-                        f' It often happen when new version of chromedriver released, but new version of chrome browser is not\n'
-                        f' Trying to download the latest previous version of chromedriver')
+                    message = (f' Problem with chromedriver latest_version_driver:'
+                        f'{latest_version_driver} latest_version_browser: {latest_version_browser}\n'
+                        ' It often happen when new version of chromedriver released, but new version of chrome browser is not\n'
+                        ' Trying to download the latest previous version of chromedriver')
                     logging.error(message)
 
                     result, message, driver_path = self.__download_driver(previous_version=True)
@@ -137,7 +137,7 @@ class ChromeDriver():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
@@ -149,12 +149,12 @@ class ChromeDriver():
         Returns:
             Tuple of bool, str and bool
 
-            result_run (bool)               : True if function passed correctly, False otherwise.
-            message_run (str)               : Empty string if function passed correctly, non-empty string if error.
-            is_equal (bool)                 : If true latest versions are both equal. Defaults to False.
-            
+            result_run (bool) : True if function passed correctly, False otherwise.
+            message_run (str) : Returns an error message if an error occurs in the function.
+            is_equal (bool)   : If true latest versions are both equal. Defaults to False.
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
         result_run : bool = False
@@ -162,10 +162,10 @@ class ChromeDriver():
         is_equal : bool = False
         latest_version_chromedriver_main : str = ''
         latest_version_browser_main : str = ''
-        
+
         try:
 
-            result, message, latest_version_chromedriver = self.__get_latest_version_chrome_driver(no_messages=True)
+            result, message, latest_version_chromedriver = self.__get_latest_version_chromedriver(no_messages=True)
             if not result:
                 logging.error(message)
                 return result, message, is_equal, latest_version_chromedriver_main, latest_version_browser_main
@@ -175,15 +175,15 @@ class ChromeDriver():
                 logging.error(message)
                 return result, message, is_equal, latest_version_chromedriver_main, latest_version_browser_main
 
-            latest_version_chromedriver_main = latest_version_chromedriver.split('.')[0]
-            latest_version_browser_main = latest_version_browser.split('.')[0]
+            latest_version_chromedriver_main = latest_version_chromedriver.split('.', maxsplit=1)[0]
+            latest_version_browser_main = latest_version_browser.split('.', maxsplit=1)[0]
 
             if int(latest_version_chromedriver_main) <= int(latest_version_browser_main):
                 is_equal = True
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
@@ -195,21 +195,21 @@ class ChromeDriver():
         Returns:
             Tuple of bool, str and str
 
-            result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
-            driver_path (str)       : Path where chromedriver was downloaded or updated.
-            
+            result_run (bool) : True if function passed correctly, False otherwise.
+            message_run (str) : Returns an error message if an error occurs in the function.
+            driver_path (str) : Path where chromedriver was downloaded or updated.
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
         result_run : bool = False
         message_run : str = ''
         driver_path : str = ''
-        
+
         try:
 
-            if self.check_driver_is_up_to_date:
+            if self.check_driver_is_up_to_date and not self.system_name:
 
                 result, message, is_driver_up_to_date, current_version, latest_version = self.__compare_current_version_and_latest_version()
                 if not result:
@@ -224,7 +224,7 @@ class ChromeDriver():
                 logging.error(message)
                 return result, message, driver_path
 
-            if self.check_driver_is_up_to_date:
+            if self.check_driver_is_up_to_date and not self.system_name:
 
                 result, message, is_driver_up_to_date, current_version, latest_version = self.__compare_current_version_and_latest_version()
                 if not result:
@@ -245,25 +245,25 @@ class ChromeDriver():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
         return result_run, message_run, driver_path
 
-    def __get_latest_version_chrome_driver(self, no_messages : bool = False) -> Tuple[bool, str, str]:
+    def __get_latest_version_chromedriver(self, no_messages : bool = False) -> Tuple[bool, str, str]:
         """Gets latest chromedriver version
 
 
         Returns:
             Tuple of bool, str and str
 
-            result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
-            latest_version (str)    : Latest version of chromedriver.
-            
+            result_run (bool)     : True if function passed correctly, False otherwise.
+            message_run (str)     : Returns an error message if an error occurs in the function.
+            latest_version (str)  : Latest version of chromedriver.
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
@@ -272,7 +272,7 @@ class ChromeDriver():
         latest_version : str = ''
 
         try:
-            
+
             url = self.setting["ChromeDriver"]["LinkLastRelease"]
             result, message, status_code, json_data = self.requests_getter.get_result_by_request(url=url)
             if not result:
@@ -287,7 +287,7 @@ class ChromeDriver():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
@@ -300,11 +300,11 @@ class ChromeDriver():
         Returns:
             Tuple of bool, str and str
 
-            result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
-            
+            result_run (bool) : True if function passed correctly, False otherwise.
+            message_run (str) : Returns an error message if an error occurs in the function.
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
@@ -313,95 +313,66 @@ class ChromeDriver():
 
         try:
 
-            if os.path.exists(self.chromedriver_path):
-                
+            if Path(self.chromedriver_path).exists():
+
                 logging.info(f'Deleted existing chromedriver chromedriver_path: {self.chromedriver_path}')
-                file_to_rem = pathlib.Path(self.chromedriver_path)
-                file_to_rem.unlink()
+                Path(self.chromedriver_path).unlink()
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
         return result_run, message_run
 
-    def __get_current_version_chrome_selenium(self) -> Tuple[bool, str, str]:
-        """Gets current chromedriver version
+    def __get_current_version_chromedriver(self) -> Tuple[bool, str, str]:
+        """Gets current chromedriver version via command in terminal
 
 
         Returns:
             Tuple of bool, str and str
 
-            result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
-            driver_version (str)    : Current chromedriver version.
+            result_run (bool)    : True if function passed correctly, False otherwise.
+            message_run (str)    : Returns an error message if an error occurs in the function.
+            driver_version (str) : Current chromedriver version.
 
         Raises:
-            SessionNotCreatedException: Occurs when current chromedriver could not start.
-
-            WebDriverException: Occurs when current chromedriver could not start or critical error occured.
 
             OSError: Occurs when chromedriver made for another CPU type
 
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
         result_run : bool = False
         message_run : str = ''
         driver_version : str = ''
-        
+        driver_version_terminal : str = ''
+
         try:
 
-            if os.path.exists(self.chromedriver_path):
-            
-                result, message, driver_version = self.__get_current_version_chrome_driver_via_terminal()
-                if not result:
-                    logging.error(message)
-                    message = 'Trying to get current version of chromedriver via webdriver'
-                    logging.info(message)
-                
-                if not result or not driver_version:
+            if Path(self.chromedriver_path).exists():
 
-                    chrome_options = webdriver.ChromeOptions()
-            
-                    chrome_options.add_argument('--headless')
+                with subprocess.Popen([self.chromedriver_path, '--version'], stdout=subprocess.PIPE) as process:
+                    driver_version_terminal = process.communicate()[0].decode('UTF-8')
 
-                    driver = webdriver.Chrome(executable_path = self.chromedriver_path, options = chrome_options)
-
-                    driver_version_selenium = str(driver.capabilities['chrome']['chromedriverVersion'])
-
-                    find_string = re.findall(self.setting["Program"]["wedriverVersionPattern"], driver_version_selenium)
-                    driver_version = find_string[0] if len(find_string) > 0 else driver_version_selenium.split(" ")[0]
-
-                    driver.close()
-                    driver.quit()
+                find_string = re.findall(self.setting["Program"]["wedriverVersionPattern"], driver_version_terminal)
+                driver_version = find_string[0] if len(find_string) > 0 else ''
 
                 logging.info(f'Current version of chromedriver: {driver_version}')
 
             result_run = True
 
-        except SessionNotCreatedException:
-            message_run = f'SessionNotCreatedException error: {traceback.format_exc()}'
-            logging.error(message_run)
-            return True, message_run, driver_version
-
-        except WebDriverException:
-            message_run = f'WebDriverException error: {traceback.format_exc()}'
-            logging.error(message_run)
-            return True, message_run, driver_version
-
         except OSError:
             message_run = f'OSError error: {traceback.format_exc()}' #probably [Errno 86] Bad CPU type in executable:
             logging.error(message_run)
             return True, message_run, driver_version
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
-        
+
         return result_run, message_run, driver_version
 
     def __compare_current_version_and_latest_version(self) -> Tuple[bool, str, bool, str, str]:
@@ -411,11 +382,11 @@ class ChromeDriver():
             Tuple of bool, str and bool
 
             result_run (bool)           : True if function passed correctly, False otherwise.
-            message_run (str)           : Empty string if function passed correctly, non-empty string if error.
+            message_run (str)           : Returns an error message if an error occurs in the function.
             is_driver_up_to_date (bool) : If true current version of chromedriver is up to date. Defaults to False.
-            
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
         result_run : bool = False
@@ -423,10 +394,10 @@ class ChromeDriver():
         is_driver_up_to_date : bool = False
         current_version : str = ''
         latest_version : str = ''
-        
+
         try:
 
-            result, message, current_version = self.__get_current_version_chrome_selenium()
+            result, message, current_version = self.__get_current_version_chromedriver()
             if not result:
                 logging.error(message)
                 return result, message, is_driver_up_to_date, current_version, latest_version
@@ -434,19 +405,19 @@ class ChromeDriver():
             if not current_version:
                 return True, message_run, is_driver_up_to_date, current_version, latest_version
 
-            result, message, latest_version = self.__get_latest_version_chrome_driver()
+            result, message, latest_version = self.__get_latest_version_chromedriver()
             if not result:
                 logging.error(message)
                 return result, message, is_driver_up_to_date, current_version, latest_version
 
             if current_version == latest_version:
                 is_driver_up_to_date = True
-                message = f'Your existing chromedriver is up to date. current_version: {current_version} latest_version: {latest_version}' 
+                message = f'Your existing chromedriver is up to date. current_version: {current_version} latest_version: {latest_version}'
                 logging.info(message)
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
@@ -458,19 +429,19 @@ class ChromeDriver():
         Returns:
             Tuple of bool and str
 
-            result_run (bool)           : True if function passed correctly, False otherwise.
-            message_run (str)           : Empty string if function passed correctly, non-empty string if error.
-            
+            result_run (bool)   : True if function passed correctly, False otherwise.
+            message_run (str)   : Returns an error message if an error occurs in the function.
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
         result_run : bool = False
         message_run : str = ''
-        
+
         try:
 
-            if os.path.exists(self.chromedriver_path):
+            if Path(self.chromedriver_path).exists():
 
                 logging.info('Trying to give chromedriver needed permissions')
 
@@ -481,7 +452,7 @@ class ChromeDriver():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
@@ -495,11 +466,11 @@ class ChromeDriver():
             Tuple of bool, str and str
 
             result_run (bool)               : True if function passed correctly, False otherwise.
-            message_run (str)               : Empty string if function passed correctly, non-empty string if error.
+            message_run (str)               : Returns an error message if an error occurs in the function.
             latest_version_previous (str)   : Latest previous version of chromedriver.
-            
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
@@ -508,7 +479,7 @@ class ChromeDriver():
         latest_version_previous : str = ''
 
         try:
-            
+
             url = self.setting["ChromeDriver"]["LinkLastRelease"]
             result, message, status_code, json_data = self.requests_getter.get_result_by_request(url=url)
             if not result:
@@ -516,12 +487,7 @@ class ChromeDriver():
                 return result, message, latest_version_previous
 
             latest_version = str(json_data)
-
-            logging.info(f'Latest version of chromedriver: {latest_version}')
-
-            latest_version_main = latest_version.split(".")[0]
-
-            logging.info(f'Latest main version of chromedriver: {latest_version_main}')
+            latest_version_main = latest_version.split(".", maxsplit=1)[0]
 
             latest_version_main_previous = int(latest_version_main) - 1
 
@@ -537,72 +503,76 @@ class ChromeDriver():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
         return result_run, message_run , latest_version_previous
 
-    def __get_current_version_chrome_driver_via_terminal(self) -> Tuple[bool, str, str]:
-        """Gets current chromedriver version via command in terminal
+    def __check_if_version_is_valid(self, url : str, version_url : str) -> Tuple[bool, str]:
+        """Checks the specified version for existence.
 
+        Args:
+            url (str)           : Full download url of chromedriver.
+            version_url (str)   : Version that will be downloaded.
 
         Returns:
-            Tuple of bool, str and str
-
-            result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
-            driver_version (str)    : Current chromedriver version.
-
-        Raises:
-
-            Except: If unexpected error raised. 
+            Tuple of bool and str
 
+            result_run (bool)   : True if function passed correctly, False otherwise.
+            message_run (str)   : Returns an error message if an error occurs in the function.
         """
-
         result_run : bool = False
         message_run : str = ''
-        driver_version : str = ''
-        driver_version_terminal : str = ''
-        
+        archive_name : str = url.split("/")[len(url.split("/"))-1]
+        url_test_valid = self.setting["ChromeDriver"]["LinkCheckVersionIsValid"].format(version_url)
+        version_valid : str = f"{version_url}/{archive_name}"
+
         try:
 
-            logging.info('Trying to get current version of chromedriver via terminal')
-        
-            process = subprocess.Popen([self.chromedriver_path, '--version'], stdout=subprocess.PIPE)
-    
-            driver_version_terminal = process.communicate()[0].decode('UTF-8')
+            result, message, status_code, json_data = self.requests_getter.get_result_by_request(url=url_test_valid)
+            if not result:
+                logging.error(message)
+                return result, message
 
-            find_string = re.findall(self.setting["Program"]["wedriverVersionPattern"], driver_version_terminal)
-            driver_version = find_string[0] if len(find_string) > 0 else ''
+            if not version_valid in json_data:
+                message = f'Wrong version or system_name was specified. version_valid: {version_valid} version_url: {version_url} url: {url}'
+                logging.error(message)
+                return False, message
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
-        
-        return result_run, message_run, driver_version
 
-    def __download_driver(self, version : str = '', previous_version : bool = False):
-        """Download specific version of phantomjs to folder
+        return result_run, message_run
+
+    def __download_driver(self, version : str = '', previous_version : bool = False) -> Tuple[bool, str, str]:
+        """Function to download, delete or upgrade current chromedriver
+
+        Args:
+            version (str)               : Specific chromedriver version to download. Defaults to empty string.
+            previous_version (boll)     : If true, chromedriver latest previous version will be downloaded. Defaults to False.
 
         Returns:
             Tuple of bool, str and str
 
-            result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
-            file_name (str)         : File name of unzipped file
-            
+            result_run (bool) : True if function passed correctly, False otherwise.
+            message_run (str) : Returns an error message if an error occurs in the function.
+            driver_path (str) : Path to unzipped driver.
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
         result_run : bool = False
         message_run : str = ''
-        file_name : str = ''
         url : str = ''
+        latest_previous_version : str = ''
+        latest_version : str = ''
+        driver_path : str = ''
 
         try:
 
@@ -611,16 +581,11 @@ class ChromeDriver():
                 result, message = self.__delete_current_chromedriver_for_current_os()
                 if not result:
                     logging.error(message)
-                    return result, message, file_name
+                    return result, message, driver_path
 
             if version:
 
                 url = self.setting["ChromeDriver"]["LinkLastReleaseFile"].format(version)
-                result, message, status_code, json_data = self.requests_getter.get_result_by_request(url=url, return_text=False)
-                if not result:
-                    logging.error(message)
-                    return result, message, file_name
-
                 logging.info(f'Started download chromedriver specific_version: {version}')
 
             elif previous_version:
@@ -628,78 +593,88 @@ class ChromeDriver():
                 result, message, latest_previous_version = self.__get_latest_previous_version_chromedriver_via_requests()
                 if not result:
                     logging.error(message)
-                    return result, message, file_name
-                
-                url = self.setting["ChromeDriver"]["LinkLastReleaseFile"].format(latest_previous_version)
+                    return result, message, driver_path
 
+                url = self.setting["ChromeDriver"]["LinkLastReleaseFile"].format(latest_previous_version)
                 logging.info(f'Started download chromedriver latest_previous_version: {latest_previous_version}')
 
             else:
 
-                result, message, latest_version = self.__get_latest_version_chrome_driver()
+                result, message, latest_version = self.__get_latest_version_chromedriver()
                 if not result:
                     logging.error(message)
-                    return result, message, file_name
+                    return result, message, driver_path
 
                 url = self.setting["ChromeDriver"]["LinkLastReleaseFile"].format(latest_version)
-
                 logging.info(f'Started download chromedriver latest_version: {latest_version}')
 
+            if self.system_name:
+                url = url.replace(url.split("/")[len(url.split("/"))-1], '')
+                url = url + self.system_name
+
+                logging.info(f'Started downloading chromedriver for specific system: {self.system_name}')
+
+            if any([version, self.system_name ,latest_previous_version]):
+                version_url = version if version else latest_previous_version if latest_previous_version else latest_version
+                result, message = self.__check_if_version_is_valid(url=url, version_url=version_url)
+                if not result:
+                    logging.error(message)
+                    return result, message, driver_path
+
             archive_name = url.split("/")[len(url.split("/"))-1]
             out_path = self.path + archive_name
 
-            if os.path.exists(out_path):
-                os.remove(out_path)
+            if Path(out_path).exists():
+                Path(out_path).unlink()
 
             logging.info(f'Started download chromedriver by url: {url}')
 
             if self.info_messages:
-                file_name = wget.download(url=url, out=out_path)
+                archive_path = wget.download(url=url, out=out_path)
             else:
-                file_name = wget.download(url=url, out=out_path, bar=None)
+                archive_path = wget.download(url=url, out=out_path, bar=None)
 
             time.sleep(2)
 
-            logging.info(f'Chromedriver was downloaded to path: {file_name}')
+            logging.info(f'Chromedriver was downloaded to path: {archive_path}')
+
+            out_path : str = self.path
+
+            parameters = dict(archive_path=archive_path, out_path=out_path)
 
             if not self.filename:
-                
-                archive_path = file_name
-                out_path = self.path
-                result, message = self.extractor.extract_all_zip_archive(archive_path=archive_path, out_path=out_path)
+
+                result, message = self.extractor.extract_and_detect_archive_format(**parameters)
                 if not result:
                     logging.error(message)
-                    return result, message, file_name
+                    return result, message, driver_path
 
             else:
 
-                archive_path = file_name
-                out_path = self.path
-                filename = self.setting['ChromeDriver']['LastReleasePlatform']
-                filename_replace = self.filename
-                result, message = self.extractor.extract_all_zip_archive_with_specific_name(archive_path=archive_path, 
-                out_path=out_path, filename=filename, filename_replace=filename_replace)
+                filename = self.setting['ChromeDriver']['LastReleasePlatform'] if not self.specific_driver_name else self.specific_driver_name
+                parameters.update(dict(filename=filename, filename_replace=self.filename))
+                result, message = self.extractor.extract_all_zip_archive_with_specific_name(**parameters)
                 if not result:
                     logging.error(message)
-                    return result, message, file_name
+                    return result, message, driver_path
 
-            if os.path.exists(file_name):
-                os.remove(file_name)
-            
-            file_name = self.chromedriver_path
+            if Path(archive_path).exists():
+                Path(archive_path).unlink()
 
-            logging.info(f'Chromedriver was successfully unpacked by path: {file_name}')
+            driver_path = self.chromedriver_path
+
+            logging.info(f'Chromedriver was successfully unpacked by path: {driver_path}')
 
             if self.chmod:
 
                 result, message = self.__chmod_driver()
                 if not result:
-                    return result, message, file_name
+                    return result, message, driver_path
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
-        return result_run, message_run, file_name
\ No newline at end of file
+        return result_run, message_run, driver_path
