@@ -1,79 +1,84 @@
+#Standart library imports
 import subprocess
-from selenium import webdriver
-import wget
 import os
 import traceback
 import logging
 import time
-import os
-from selenium.common.exceptions import SessionNotCreatedException
-from selenium.common.exceptions import WebDriverException
+from typing import Tuple, Any
+import re
+from pathlib import Path
+import platform
+import stat
 
-from selenium.webdriver.firefox.options import Options as FirefoxOptions
+# Third party imports
+import wget
 
-from typing import Tuple
-
-import sys
-import os.path
-sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__))))
+# Local imports
 
 from _setting import setting
 
-import platform
-
-import stat
-
 from util.extractor import Extractor
 from util.github_viewer import GithubViewer
 from util.requests_getter import RequestsGetter
+
 from browsers._firefoxBrowser import FirefoxBrowser
 
-import re
-
-import pathlib
-
 class GeckoDriver():
+    """Class for working with Selenium geckodriver binary"""
 
     _repo_name = 'mozilla/geckodriver'
-    
-    def __init__(self, path : str,**kwargs):
-        """Class for working with Selenium geckodriver binary
 
-        Args:
-            path (str)                          : Specified path which will used for downloading or updating Selenium geckodriver binary. Must be folder path.
-            upgrade (bool)                      : If true, it will overwrite existing driver in the folder. Defaults to False.
-            chmod (bool)                        : If true, it will make geckodriver binary executable. Defaults to True.
-            check_driver_is_up_to_date (bool)   : If true, it will check driver version before and after upgrade. Defaults to False.
-            filename (str)                      : Specific name for geckodriver. If given, it will replace name for geckodriver.
-            version (str)                       : Specific version for geckodriver. If given, it will downloads given version.
-            check_browser_is_up_to_date (bool)  : If true, it will check firefox browser version before geckodriver update or upgrade.
-        """
-        self.setting = setting
+    def __init__(self, **kwargs):
+
+        self.setting : Any = setting
+
+        self.path : str = str(kwargs.get('path'))
 
-        self.path : str = path
-                    
         self.upgrade : bool = bool(kwargs.get('upgrade'))
 
         self.chmod : bool = bool(kwargs.get('chmod'))
 
         self.check_driver_is_up_to_date : bool = bool(kwargs.get('check_driver_is_up_to_date'))
-        
-        specific_filename = str(kwargs.get('filename'))
-        self.filename = f"{specific_filename}.exe" if platform.system() == 'Windows' and specific_filename else\
-                        specific_filename
 
-        self.geckodriver_path : str =  self.path + self.setting['GeckoDriver']['LastReleasePlatform'] if not specific_filename else self.path + self.filename
+        self.specific_driver_name = ''
+        self.system_name = ''
+
+        specific_system = str(kwargs.get('system_name', ''))
+        specific_system = specific_system.replace('mac64_m1', 'macos-aarch64').replace('mac64', 'macos')
+
+        if specific_system:
+            if 'win' in specific_system:
+                self.system_name = "geckodriver-v{}-" + f"{specific_system}.zip"
+            else:
+                self.system_name = "geckodriver-v{}-" + f"{specific_system}.tar.gz"
+
+            specific_filename = str(kwargs.get('filename'))
+            self.filename = f"{specific_filename}.exe" if 'win' in specific_system and specific_filename else\
+                            specific_filename
+
+            self.specific_driver_name =    "geckodriver.exe" if 'win' in specific_system else\
+                                    "geckodriver"
+
+            name = self.specific_driver_name
+
+        else:
+
+            specific_filename = str(kwargs.get('filename'))
+            self.filename = f"{specific_filename}.exe" if platform.system() == 'Windows' and specific_filename else\
+                            specific_filename
+
+            name = self.setting['GeckoDriver']['LastReleasePlatform']
+
+        self.geckodriver_path : str =  self.path + name if not specific_filename else self.path + self.filename
 
         self.version = str(kwargs.get('version'))
 
-        self.check_browser_is_up_to_date = bool(kwargs.get('check_browser_is_up_to_date'))
-
         self.info_messages = bool(kwargs.get('info_messages'))
 
         self.extractor = Extractor
         self.github_viewer = GithubViewer
         self.requests_getter = RequestsGetter
-        self.firefoxbrowser = FirefoxBrowser(path=self.path, check_browser_is_up_to_date=self.check_browser_is_up_to_date)
+        self.firefoxbrowser = FirefoxBrowser(**kwargs)
 
     def main(self) -> Tuple[bool, str, str]:
         """Main function, checks for the latest version, downloads or updates geckodriver binary or
@@ -82,18 +87,18 @@ class GeckoDriver():
         Returns:
             Tuple of bool, str and str
 
-            result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
-            driver_path (str)       : Path where geckodriver was downloaded or updated.
-            
+            result_run (bool) : True if function passed correctly, False otherwise.
+            message_run (str) : Returns an error message if an error occurs in the function.
+            driver_path (str) : Path where geckodriver was downloaded or updated.
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
         result_run : bool = False
         message_run : str = ''
         driver_path : str = ''
-        
+
         try:
 
             result, message = self.firefoxbrowser.main()
@@ -117,80 +122,59 @@ class GeckoDriver():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
         return result_run, message_run, driver_path
 
-    def __get_current_version_geckodriver_selenium(self) -> Tuple[bool, str, str]:
-        """Gets current geckodriver version
+    def __get_current_version_geckodriver(self) -> Tuple[bool, str, str]:
+        """Gets current geckodriver version via command in terminal
 
 
         Returns:
             Tuple of bool, str and str
 
             result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
-            driver_version (str)    : Current driver version.
+            message_run (str)       : Returns an error message if an error occurs in the function.
+            driver_version (str)    : Current geckodriver version.
 
         Raises:
-            SessionNotCreatedException: Occurs when current geckodriver could not start.
-            
-            WebDriverException: Occurs when current geckodriver could not start or critical error occured.
 
-            OSError: Occurs when geckodriver made for another CPU type
+            OSError: Occurs when geckodriver maded for another CPU type
 
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
         result_run : bool = False
         message_run : str = ''
         driver_version : str = ''
+        driver_version_terminal : str = ''
+
         try:
 
-            if os.path.exists(self.geckodriver_path):
-            
-                result, message, driver_version = self.__get_current_version_geckodriver_via_terminal()
-                if not result:
-                    logging.error(message)
-                    message = 'Trying to get current version of geckodriver via webdriver'
-                    logging.info(message)
-                
-                if not result or not driver_version:
+            if Path(self.geckodriver_path).exists():
 
-                    options = FirefoxOptions()
-                    options.add_argument("--headless")
+                with subprocess.Popen([self.geckodriver_path, '--version'], stdout=subprocess.PIPE) as process:
+                    driver_version_terminal = process.communicate()[0].decode('UTF-8')
 
-                    driver = webdriver.Firefox(executable_path = self.geckodriver_path, options=options)
-                    driver_version = str(driver.capabilities['moz:geckodriverVersion'])
-                    driver.close()
-                    driver.quit()
+                find_string = re.findall(self.setting["Program"]["wedriverVersionPattern"], driver_version_terminal)
+                driver_version = find_string[0] if len(find_string) > 0 else ''
 
                 logging.info(f'Current version of geckodriver: {driver_version}')
 
             result_run = True
 
-        except SessionNotCreatedException:
-            message_run = f'SessionNotCreatedException error: {traceback.format_exc()}'
-            logging.error(message_run)
-            return True, message_run, driver_version
-        
-        except WebDriverException:
-            message_run = f'WebDriverException error: {traceback.format_exc()}'
-            logging.error(message_run)
-            return True, message_run, driver_version
-
         except OSError:
             message_run = f'OSError error: {traceback.format_exc()}' #probably [Errno 86] Bad CPU type in executable:
             logging.error(message_run)
             return True, message_run, driver_version
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
-        
+
         return result_run, message_run, driver_version
 
     def __get_latest_version_geckodriver(self) -> Tuple[bool, str, str]:
@@ -201,11 +185,11 @@ class GeckoDriver():
             Tuple of bool, str and str
 
             result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
+            message_run (str)       : Returns an error message if an error occurs in the function.
             latest_version (str)    : Latest version of geckodriver
-            
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
@@ -214,7 +198,7 @@ class GeckoDriver():
         latest_version : str = ''
 
         try:
-            
+
             repo_name = GeckoDriver._repo_name
             result, message, json_data = self.github_viewer.get_latest_release_data_by_repo_name(repo_name=repo_name)
             if not result:
@@ -226,7 +210,7 @@ class GeckoDriver():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
@@ -239,11 +223,11 @@ class GeckoDriver():
         Returns:
             Tuple of bool, str and str
 
-            result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
-            
+            result_run (bool) : True if function passed correctly, False otherwise.
+            message_run (str) : Returns an error message if an error occurs in the function.
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
@@ -252,20 +236,19 @@ class GeckoDriver():
 
         try:
 
-            if os.path.exists(self.geckodriver_path):
+            if Path(self.geckodriver_path).exists():
                 logging.info(f'Deleted existing geckodriver geckodriver_path: {self.geckodriver_path}')
-                file_to_rem = pathlib.Path(self.geckodriver_path)
-                file_to_rem.unlink()
-            
+                Path(self.geckodriver_path).unlink()
+
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
         return result_run, message_run
-    
+
     def __check_if_geckodriver_is_up_to_date(self) -> Tuple[bool, str, str]:
         """Main function, checks for the latest version, downloads or updates geckodriver binary
 
@@ -273,20 +256,20 @@ class GeckoDriver():
             Tuple of bool, str and str
 
             result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
+            message_run (str)       : Returns an error message if an error occurs in the function.
             driver_path (str)       : Path where geckodriver was downloaded or updated.
-            
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
         result_run : bool = False
         message_run : str = ''
         driver_path : str = ''
-        
+
         try:
 
-            if self.check_driver_is_up_to_date:
+            if self.check_driver_is_up_to_date and not self.system_name:
 
                 result, message, is_driver_up_to_date, current_version, latest_version = self.__compare_current_version_and_latest_version()
                 if not result:
@@ -301,7 +284,7 @@ class GeckoDriver():
                 logging.error(message)
                 return result, message, driver_path
 
-            if self.check_driver_is_up_to_date:
+            if self.check_driver_is_up_to_date and not self.system_name:
 
                 result, message, is_driver_up_to_date, current_version, latest_version = self.__compare_current_version_and_latest_version()
                 if not result:
@@ -321,7 +304,7 @@ class GeckoDriver():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
@@ -334,11 +317,11 @@ class GeckoDriver():
             Tuple of bool, str and bool
 
             result_run (bool)           : True if function passed correctly, False otherwise.
-            message_run (str)           : Empty string if function passed correctly, non-empty string if error.
+            message_run (str)           : Returns an error message if an error occurs in the function.
             is_driver_up_to_date (bool) : If true current version of geckodriver is up to date. Defaults to False.
-            
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
         result_run : bool = False
@@ -346,10 +329,10 @@ class GeckoDriver():
         is_driver_up_to_date : bool = False
         current_version : str = ''
         latest_version : str = ''
-        
+
         try:
 
-            result, message, current_version = self.__get_current_version_geckodriver_selenium()
+            result, message, current_version = self.__get_current_version_geckodriver()
             if not result:
                 logging.error(message)
                 return result, message, is_driver_up_to_date, current_version, latest_version
@@ -369,7 +352,7 @@ class GeckoDriver():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
@@ -382,18 +365,18 @@ class GeckoDriver():
             Tuple of bool and str
 
             result_run (bool)           : True if function passed correctly, False otherwise.
-            message_run (str)           : Empty string if function passed correctly, non-empty string if error.
-            
+            message_run (str)           : Returns an error message if an error occurs in the function.
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
         result_run : bool = False
         message_run : str = ''
-        
+
         try:
 
-            if os.path.exists(self.geckodriver_path):
+            if Path(self.geckodriver_path).exists():
 
                 logging.info('Trying to give geckodriver needed permissions')
 
@@ -404,55 +387,12 @@ class GeckoDriver():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
         return result_run, message_run
 
-    def __get_current_version_geckodriver_via_terminal(self) -> Tuple[bool, str, str]:
-        """Gets current geckodriver version via command in terminal
-
-
-        Returns:
-            Tuple of bool, str and str
-
-            result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
-            driver_version (str)    : Current geckodriver version.
-
-        Raises:
-
-            Except: If unexpected error raised. 
-
-        """
-
-        result_run : bool = False
-        message_run : str = ''
-        driver_version : str = ''
-        driver_version_terminal : str = ''
-        
-        try:
-            
-            if os.path.exists(self.geckodriver_path):
-
-                logging.info('Trying to get current version of geckodriver via terminal')
-            
-                process = subprocess.Popen([self.geckodriver_path, '--version'], stdout=subprocess.PIPE)
-        
-                driver_version_terminal = process.communicate()[0].decode('UTF-8')
-                
-                find_string = re.findall(self.setting["GeckoDriver"]["geckodriverVersionPattern"], driver_version_terminal)
-                driver_version = find_string[0] if len(find_string) > 0 else ''
-
-            result_run = True
-
-        except:
-            message_run = f'Unexcepted error: {traceback.format_exc()}'
-            logging.error(message_run)
-        
-        return result_run, message_run, driver_version
-
     def __get_latest_previous_version_geckodriver_via_requests(self) -> Tuple[bool, str, str]:
         """Gets previous latest geckodriver version
 
@@ -461,11 +401,11 @@ class GeckoDriver():
             Tuple of bool, str and str
 
             result_run (bool)               : True if function passed correctly, False otherwise.
-            message_run (str)               : Empty string if function passed correctly, non-empty string if error.
+            message_run (str)               : Returns an error message if an error occurs in the function.
             latest_version_previous (str)   : Latest previous version of geckodriver.
-            
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
@@ -476,47 +416,94 @@ class GeckoDriver():
         try:
 
             repo_name = GeckoDriver._repo_name
-            result, message, json_data = self.github_viewer.get_all_releases_tags_by_repo_name(repo_name=repo_name)
+            result, message, json_data = self.github_viewer.get_all_releases_data_by_repo_name(repo_name=repo_name)
             if not result:
                 return result, message, latest_previous_version
 
-            for data in json_data:
-                if not 'v' in data.get("ref"):
-                    del json_data[json_data.index(data)]
-
-            find_string = json_data[len(json_data)-2].get('ref').split('/')
-            latest_previous_version = find_string[len(find_string)-1]
+            latest_previous_version = latest_previous_version = json_data[1].get('name')
 
             logging.info(f'Latest previous version of geckodriver: {latest_previous_version}')
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
         return result_run, message_run , latest_previous_version
-        
-    def __download_driver(self, version : str = '', previous_version : bool = False):
-        """Download specific version of phantomjs to folder
+
+    def __check_if_version_is_valid(self, url : str, version_url : str) -> Tuple[bool, str]:
+        """Checks the specified version for existence.
+
+        Args:
+            url (str)           : Full download url of geckodriver.
+            version_url (str)   : Version that will be downloaded.
+
+        Returns:
+            Tuple of bool and str
+
+            result_run (bool)       : True if function passed correctly, False otherwise.
+            message_run (str)       : Returns an error message if an error occurs in the function.
+        """
+        result_run : bool = False
+        message_run : str = ''
+        archive_name : str = url.split("/")[len(url.split("/"))-1]
+        is_found : bool = False
+
+        try:
+
+            result, message, json_data = self.github_viewer.get_all_releases_data_by_repo_name(GeckoDriver._repo_name)
+            if not result:
+                logging.error(message)
+                return result, message
+
+            for data in json_data:
+                if data.get('name') == version_url:
+                    for asset in data.get('assets'):
+                        if asset.get('name') == archive_name:
+                            is_found = True
+                            break
+                    break
+
+            if not is_found:
+                message = f'Wrong version or system_name was specified. version_url: {version_url} url: {url}'
+                logging.error(message)
+                return False, message
+
+            result_run = True
+
+        except Exception:
+            message_run = f'Unexcepted error: {traceback.format_exc()}'
+            logging.error(message_run)
+
+        return result_run, message_run
+
+    def __download_driver(self, version : str = '', previous_version : bool = False) -> Tuple[bool, str, str]:
+        """Function to download, delete or upgrade current geckodriver
+
+        Args:
+            version (str)               : Specific geckodriver version to download. Defaults to empty string.
+            previous_version (boll)     : If true, geckodriver latest previous version will be downloaded. Defaults to False.
 
         Returns:
             Tuple of bool, str and str
 
             result_run (bool)       : True if function passed correctly, False otherwise.
             message_run (str)       : Empty string if function passed correctly, non-empty string if error.
-            file_name (str)         : File name of unzipped file
-            
+            driver_path (str)       : Path to unzipped driver.
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
         result_run : bool = False
         message_run : str = ''
-        file_name : str = ''
         url : str = ''
         latest_version : str = ''
+        latest_previous_version : str = ''
+
+        driver_path : str = ''
 
         try:
 
@@ -525,17 +512,11 @@ class GeckoDriver():
                 result, message = self.__delete_current_geckodriver_for_current_os()
                 if not result:
                     logging.error(message)
-                    return result, message, file_name
+                    return result, message, driver_path
 
             if version:
                 
-                latest_version_url = "v" + version 
-                url = self.setting["GeckoDriver"]["LinkLastReleasePlatform"].format(latest_version_url, latest_version_url)
-                result, message, status_code, json_data = self.requests_getter.get_result_by_request(url=url, return_text=False)
-                if not result:
-                    logging.error(message)
-                    return result, message, file_name
-                
+                url = self.setting["GeckoDriver"]["LinkLastReleasePlatform"].format(version, version)
                 logging.info(f'Started download geckodriver specific_version: {version}')
 
             elif previous_version:
@@ -543,10 +524,9 @@ class GeckoDriver():
                 result, message, latest_previous_version = self.__get_latest_previous_version_geckodriver_via_requests()
                 if not result:
                     logging.error(message)
-                    return result, message, file_name
+                    return result, message, driver_path
 
                 url = self.setting["GeckoDriver"]["LinkLastReleasePlatform"].format(latest_previous_version, latest_previous_version)
-                
                 logging.info(f'Started download geckodriver latest_previous_version: {latest_previous_version}')
 
             else:
@@ -554,83 +534,78 @@ class GeckoDriver():
                 result, message, latest_version = self.__get_latest_version_geckodriver()
                 if not result:
                     logging.error(message)
-                    return result, message, file_name
+                    return result, message, driver_path
 
-                latest_version_url = "v" + latest_version
-                url = self.setting["GeckoDriver"]["LinkLastReleasePlatform"].format(latest_version_url, latest_version_url)
-                
+                url = self.setting["GeckoDriver"]["LinkLastReleasePlatform"].format(latest_version, latest_version)
                 logging.info(f'Started download geckodriver latest_version: {latest_version}')
 
+            if self.system_name:
+                url = url.replace(url.split("/")[len(url.split("/"))-1], '')
+                url = url + self.system_name.format(latest_version) if latest_version else url + self.system_name.format(latest_previous_version) if latest_previous_version else\
+                url + self.system_name.format(version)    
+
+                logging.info(f'Started downloading geckodriver for specific system: {self.system_name}')
+
+            if any([version, self.system_name ,latest_previous_version]):
+                version_url = version if version else latest_previous_version if latest_previous_version else latest_version
+                result, message = self.__check_if_version_is_valid(url=url, version_url=version_url)
+                if not result:
+                    logging.error(message)
+                    return result, message, driver_path
+
             archive_name = url.split("/")[len(url.split("/"))-1]
             out_path = self.path + archive_name
 
-            if os.path.exists(out_path):
-                os.remove(out_path)
+            if Path(out_path).exists():
+                Path(out_path).unlink()
 
             logging.info(f'Started download geckodriver by url: {url}')
 
             if self.info_messages:
-                file_name = wget.download(url=url, out=out_path)
+                archive_path = wget.download(url=url, out=out_path)
             else:
-                file_name = wget.download(url=url, out=out_path, bar=None)
+                archive_path = wget.download(url=url, out=out_path, bar=None)
             time.sleep(2)
 
-            logging.info(f'Geckodriver was downloaded to path: {file_name}')
+            logging.info(f'Geckodriver was downloaded to path: {archive_path}')
+
+            out_path = self.path
+
+            parameters = dict(archive_path=archive_path, out_path=out_path)
 
             if not self.filename:
 
-                if archive_name.endswith('.tar.gz'):
-
-                    archive_path = file_name
-                    out_path = self.path
-                    result, message = self.extractor.extract_all_tar_gz_archive(archive_path=archive_path, out_path=out_path)
-                    if not result:
-                        logging.error(message)
-                        return result, message, file_name
-
-                elif archive_name.endswith('.zip'):
-
-                    archive_path = file_name
-                    out_path = self.path
-                    result, message = self.extractor.extract_all_zip_archive(archive_path=archive_path, out_path=out_path)
-                    if not result:
-                        logging.error(message)
-                        return result, message, file_name
-
-                else:
-                    message = f'Unknown archive format was specified archive_name: {archive_name}'
-                    logging.error(message)
-                    return result_run, message, file_name
-
-            else:
-
-                archive_path = file_name
-                out_path = self.path
-                filename = self.setting['GeckoDriver']['LastReleasePlatform']
-                filename_replace = self.filename
-                result, message = self.extractor.extract_all_zip_archive_with_specific_name(archive_path=archive_path, 
-                out_path=out_path, filename=filename, filename_replace=filename_replace)
+                result, message = self.extractor.extract_and_detect_archive_format(**parameters)
                 if not result:
                     logging.error(message)
-                    return result, message, file_name
+                    return result, message, driver_path
 
-            if os.path.exists(file_name):
-                os.remove(file_name)
+            else:
+                filename = self.setting['GeckoDriver']['LastReleasePlatform'] if not self.specific_driver_name else self.specific_driver_name
+                parameters.update(dict(filename=filename, filename_replace=self.filename))
+                result, message = self.extractor.extract_all_zip_archive_with_specific_name(**parameters)
+                if not result:
+                    logging.error(message)
+                    return result, message, driver_path
 
-            file_name = self.geckodriver_path
+            if Path(archive_path).exists():
+                Path(archive_path).unlink()
 
-            logging.info(f'Geckodriver was successfully unpacked by path: {file_name}')
+            driver_path = self.geckodriver_path
+
+            logging.info(f'Geckodriver was successfully unpacked by path: {driver_path}')
 
             if self.chmod:
 
                 result, message = self.__chmod_driver()
                 if not result:
-                    return result, message, file_name
+                    return result, message, driver_path
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
-        return result_run, message_run, file_name
\ No newline at end of file
+        return result_run, message_run, driver_path
+        
\ No newline at end of file
