@@ -1,82 +1,84 @@
+#Standart library imports
 import shutil
 import subprocess
-from selenium import webdriver
-import wget
 import os
 import traceback
 import logging
 import time
-import os
+from typing import Tuple, Any
+import platform
+import stat
+from shutil import copyfile
+from pathlib import Path
+import re
+
+# Third party imports
+import wget
 from selenium.common.exceptions import SessionNotCreatedException
 from selenium.common.exceptions import WebDriverException
 
-from typing import Tuple
-
-import sys
-import os.path
-sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__))))
-
+# Local imports
 from _setting import setting
 
-import platform
-
-import stat
-
-from shutil import copyfile
-
 from util.extractor import Extractor
 from util.github_viewer import GithubViewer
+
 from util.requests_getter import RequestsGetter
 from browsers._operaBrowser import OperaBrowser
 
-from bs4 import BeautifulSoup
-
-import pathlib
-
-import re
-
 class OperaDriver():
+    """Class for working with Selenium operadriver binary"""
 
     _repo_name = 'operasoftware/operachromiumdriver'
-    
-    def __init__(self, path : str, **kwargs):
-        """Class for working with Selenium operadriver binary
 
-        Args:
-            path (str)                          : Specified path which will used for downloading or updating Selenium operadriver binary. Must be folder path.
-            upgrade (bool)                      : If true, it will overwrite existing driver in the folder. Defaults to False.
-            chmod (bool)                        : If true, it will make operadriver binary executable. Defaults to True.
-            check_driver_is_up_to_date (bool)   : If true, it will check driver version before and after upgrade. Defaults to False.
-            filename (str)                      : Specific name for operadriver. If given, it will replace name for operadriver. Defaults to empty string.
-            version (str)                       : Specific version for operadriver. If given, it will downloads given version. Defaults to empty string.
-            check_browser_is_up_to_date (bool)  : If true, it will check opera browser version before operadriver update/upgrade.
-        """
-        self.setting = setting
+    def __init__(self, **kwargs):
+
+        self.setting : Any = setting
+
+        self.path : str = str(kwargs.get('path'))
 
-        self.path : str = path
-                    
         self.upgrade : bool = bool(kwargs.get('upgrade'))
 
         self.chmod : bool = bool(kwargs.get('chmod'))
 
         self.check_driver_is_up_to_date : bool = bool(kwargs.get('check_driver_is_up_to_date'))
-        
-        specific_filename = str(kwargs.get('filename'))
-        self.filename = f"{specific_filename}.exe" if platform.system() == 'Windows' and specific_filename else\
-                        specific_filename
 
-        self.operadriver_path : str =  self.path + self.setting['OperaDriver']['LastReleasePlatform'] if not specific_filename else self.path + self.filename
+        self.specific_driver_name = ''
+        self.system_name = ''
+
+        specific_filename = str(kwargs.get('filename'))
+
+        specific_system = str(kwargs.get('system_name', ''))
+        specific_system = specific_system.replace('linux32', 'linux64')
+
+        if specific_system:
+            self.system_name = f"operadriver_{specific_system}.zip"
+
+            self.filename = f"{specific_filename}.exe" if 'windows' in specific_system and specific_filename else\
+                            specific_filename
+
+            self.specific_driver_name =    "operadriver.exe" if 'win' in specific_system else\
+                                            "operadriver"
+
+            name = self.specific_driver_name
+
+        else:
+
+            self.filename = f"{specific_filename}.exe" if platform.system() == 'Windows' and specific_filename else\
+                            specific_filename
+
+            name = self.setting['OperaDriver']['LastReleasePlatform']
+
+        self.operadriver_path : str =  self.path + name if not specific_filename else self.path + self.filename
 
         self.version = str(kwargs.get('version'))
 
-        self.check_browser_is_up_to_date = bool(kwargs.get('check_browser_is_up_to_date'))
-
         self.info_messages = bool(kwargs.get('info_messages'))
 
         self.extractor = Extractor
         self.github_viewer = GithubViewer
         self.requests_getter = RequestsGetter
-        self.operabrowser = OperaBrowser(path=self.path, check_browser_is_up_to_date=self.check_browser_is_up_to_date)
+        self.operabrowser = OperaBrowser(**kwargs)
 
     def main(self) -> Tuple[bool, str, str]:
         """Main function, checks for the latest version, downloads or updates operadriver binary or
@@ -86,17 +88,17 @@ class OperaDriver():
             Tuple of bool, str and str
 
             result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
+            message_run (str)       : Returns an error message if an error occurs in the function.
             driver_path (str)       : Path where operadriver was downloaded or updated.
-            
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
         result_run : bool = False
         message_run : str = ''
         driver_path : str = ''
-        
+
         try:
 
             result, message = self.operabrowser.main()
@@ -120,59 +122,48 @@ class OperaDriver():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
         return result_run, message_run, driver_path
 
-    def __get_current_version_operadriver_selenium(self) -> Tuple[bool, str, str]:
-        """Gets current operadriver version
+    def __get_current_version_operadriver(self) -> Tuple[bool, str, str]:
+        """Gets current operadriver version via command in terminal
 
 
         Returns:
             Tuple of bool, str and str
 
             result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
-            driver_version (str)    : Current driver version
+            message_run (str)       : Returns an error message if an error occurs in the function.
+            driver_version (str)    : Current operadriver version.
 
         Raises:
-            SessionNotCreatedException: Occurs when current operadriver could not start.
+            SessionNotCreatedException: Occurs when current edgedriver could not start.
 
-            WebDriverException: Occurs when current operadriver could not start or critical error occured
+            WebDriverException: Occurs when current edgedriver could not start or critical error occured
 
-            OSError: Occurs when operadriver made for another CPU type
+            OSError: Occurs when chromedriver made for another CPU type
 
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
         result_run : bool = False
         message_run : str = ''
         driver_version : str = ''
+        driver_version_terminal : str = ''
 
         try:
 
-            if os.path.exists(self.operadriver_path):
+            if Path(self.operadriver_path).exists():
 
-                result, message, driver_version = self.__get_current_version_operadriver_via_terminal()
-                if not result:
-                    logging.error(message)
-                    message = 'Trying to get current version of operadriver via webdriver'
-                    logging.info(message)
-                
-                if not result or not driver_version:
+                with subprocess.Popen([self.operadriver_path, '--version'], stdout=subprocess.PIPE) as process:
+                    driver_version_terminal = process.communicate()[0].decode('UTF-8')
 
-                    driver = webdriver.Opera(executable_path = self.operadriver_path)
-
-                    driver_version_selenium = str(driver.capabilities['opera']['operadriverVersion'])
-
-                    find_string = re.findall(self.setting["Program"]["wedriverVersionPattern"], driver_version_selenium)
-                    driver_version = find_string[0] if len(find_string) > 0 else driver_version_selenium.split(' ')[0]
-
-                    driver.close()
-                    driver.quit()
+                find_string = re.findall(self.setting["Program"]["wedriverVersionPattern"], driver_version_terminal)
+                driver_version = find_string[0] if len(find_string) > 0 else ''
 
                 logging.info(f'Current version of operadriver: {driver_version}')
 
@@ -193,10 +184,10 @@ class OperaDriver():
             logging.error(message_run)
             return True, message_run, driver_version
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
-        
+
         return result_run, message_run, driver_version
 
     def __get_latest_version_operadriver(self) -> Tuple[bool, str, str]:
@@ -207,11 +198,11 @@ class OperaDriver():
             Tuple of bool, str and str
 
             result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
+            message_run (str)       : Returns an error message if an error occurs in the function.
             latest_version (str)    : Latest version of operadriver
-            
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
@@ -220,7 +211,7 @@ class OperaDriver():
         latest_version : str = ''
 
         try:
-            
+
             repo_name = OperaDriver._repo_name
             result, message, json_data = self.github_viewer.get_latest_release_data_by_repo_name(repo_name=repo_name)
             if not result:
@@ -232,7 +223,7 @@ class OperaDriver():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
@@ -246,10 +237,10 @@ class OperaDriver():
             Tuple of bool, str and str
 
             result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
-            
+            message_run (str)       : Returns an error message if an error occurs in the function.
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
@@ -258,20 +249,19 @@ class OperaDriver():
 
         try:
 
-            if os.path.exists(self.operadriver_path):
+            if Path(self.operadriver_path).exists():
                 logging.info(f'Deleted existing operadriver operadriver_path: {self.operadriver_path}')
-                file_to_rem = pathlib.Path(self.operadriver_path)
-                file_to_rem.unlink()
-            
+                Path(self.operadriver_path).unlink()
+
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
         return result_run, message_run
-    
+
     def __check_if_operadriver_is_up_to_date(self) -> Tuple[bool, str, str]:
         """Main function, checks for the latest version, downloads or updates operadriver binary
 
@@ -279,20 +269,20 @@ class OperaDriver():
             Tuple of bool, str and str
 
             result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
+            message_run (str)       : Returns an error message if an error occurs in the function.
             driver_path (str)       : Path where operadriver was downloaded or updated.
-            
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
         result_run : bool = False
         message_run : str = ''
         driver_path : str = ''
-        
+
         try:
 
-            if self.check_driver_is_up_to_date:
+            if self.check_driver_is_up_to_date and not self.system_name:
 
                 result, message, is_driver_up_to_date, current_version, latest_version = self.__compare_current_version_and_latest_version()
                 if not result:
@@ -307,7 +297,7 @@ class OperaDriver():
                 logging.error(message)
                 return result, message, driver_path
 
-            if self.check_driver_is_up_to_date:
+            if self.check_driver_is_up_to_date and not self.system_name:
 
                 result, message, is_driver_up_to_date, current_version, latest_version = self.__compare_current_version_and_latest_version()
                 if not result:
@@ -315,7 +305,8 @@ class OperaDriver():
                     return result, message, driver_path
 
                 if not is_driver_up_to_date:
-                    message = f'Problem with updating operadriver current_version: {current_version} latest_version: {latest_version}'
+                    message = ('Problem with updating operadriver'
+                                f'current_version: {current_version} latest_version: {latest_version}')
                     logging.error(message)
                     message = 'Trying to download previous latest version of operadriver'
                     logging.info(message)
@@ -327,7 +318,7 @@ class OperaDriver():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
@@ -340,11 +331,11 @@ class OperaDriver():
             Tuple of bool, str and bool
 
             result_run (bool)           : True if function passed correctly, False otherwise.
-            message_run (str)           : Empty string if function passed correctly, non-empty string if error.
+            message_run (str)           : Returns an error message if an error occurs in the function.
             is_driver_up_to_date (bool) : If true current version of operadriver is up to date. Defaults to False.
-            
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
         result_run : bool = False
@@ -352,10 +343,10 @@ class OperaDriver():
         is_driver_up_to_date : bool = False
         current_version : str = ''
         latest_version : str = ''
-        
+
         try:
 
-            result, message, current_version = self.__get_current_version_operadriver_selenium()
+            result, message, current_version = self.__get_current_version_operadriver()
             if not result:
                 logging.error(message)
                 return result, message, is_driver_up_to_date, current_version, latest_version
@@ -370,12 +361,13 @@ class OperaDriver():
 
             if current_version == latest_version:
                 is_driver_up_to_date = True
-                message = f'Your existing operadriver is up to date. current_version: {current_version} latest_version: {latest_version}' 
+                message = ('Your existing operadriver is up to date.' 
+                        f'current_version: {current_version} latest_version: {latest_version}')
                 logging.info(message)
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
@@ -392,34 +384,34 @@ class OperaDriver():
             Tuple of bool, str and bool
 
             result_run (bool)           : True if function passed correctly, False otherwise.
-            message_run (str)           : Empty string if function passed correctly, non-empty string if error.
-            
+            message_run (str)           : Returns an error message if an error occurs in the function.
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
         result_run : bool = False
         message_run : str = ''
         renamed_driver_path : str = ''
-        
+
         try:
 
             new_path = archive_folder_path + os.path.sep + self.filename
 
-            if os.path.exists(new_path):
-                os.remove(new_path)
+            if Path(new_path).exists():
+                Path(new_path).unlink()
 
             os.rename(archive_operadriver_path, new_path)
-            
+
             renamed_driver_path = self.path + self.filename
-            if os.path.exists(renamed_driver_path):
-                os.remove(renamed_driver_path)
+            if Path(renamed_driver_path).exists():
+                Path(renamed_driver_path).unlink()
 
             copyfile(new_path, renamed_driver_path)
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
@@ -432,18 +424,18 @@ class OperaDriver():
             Tuple of bool and str
 
             result_run (bool)           : True if function passed correctly, False otherwise.
-            message_run (str)           : Empty string if function passed correctly, non-empty string if error.
-            
+            message_run (str)           : Returns an error message if an error occurs in the function.
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
         result_run : bool = False
         message_run : str = ''
-        
+
         try:
 
-            if os.path.exists(self.operadriver_path):
+            if Path(self.operadriver_path).exists():
 
                 logging.info('Trying to give operadriver needed permissions')
 
@@ -454,55 +446,12 @@ class OperaDriver():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
         return result_run, message_run
 
-    def __get_current_version_operadriver_via_terminal(self) -> Tuple[bool, str, str]:
-        """Gets current operadriver version via command in terminal
-
-
-        Returns:
-            Tuple of bool, str and str
-
-            result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
-            driver_version (str)    : Current operadriver version.
-
-        Raises:
-
-            Except: If unexpected error raised. 
-
-        """
-
-        result_run : bool = False
-        message_run : str = ''
-        driver_version : str = ''
-        driver_version_terminal : str = ''
-        
-        try:
-            
-            if os.path.exists(self.operadriver_path):
-
-                logging.info('Trying to get current version of operadriver via terminal')
-            
-                process = subprocess.Popen([self.operadriver_path, '--version'], stdout=subprocess.PIPE)
-        
-                driver_version_terminal = process.communicate()[0].decode('UTF-8')
-                
-                find_string = re.findall(self.setting["Program"]["wedriverVersionPattern"], driver_version_terminal)
-                driver_version = find_string[0] if len(find_string) > 0 else ''
-
-            result_run = True
-
-        except:
-            message_run = f'Unexcepted error: {traceback.format_exc()}'
-            logging.error(message_run)
-        
-        return result_run, message_run, driver_version
-    
     def __get_latest_previous_version_operadriver_via_requests(self) -> Tuple[bool, str, str]:
         """Gets previous latest operadriver version
 
@@ -511,11 +460,11 @@ class OperaDriver():
             Tuple of bool, str and str
 
             result_run (bool)               : True if function passed correctly, False otherwise.
-            message_run (str)               : Empty string if function passed correctly, non-empty string if error.
+            message_run (str)               : Returns an error message if an error occurs in the function.
             latest_version_previous (str)   : Latest previous version of operadriver.
-            
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
@@ -526,43 +475,93 @@ class OperaDriver():
         try:
 
             repo_name = OperaDriver._repo_name
-            result, message, json_data = self.github_viewer.get_all_releases_tags_by_repo_name(repo_name=repo_name)
+            result, message, json_data = self.github_viewer.get_all_releases_data_by_repo_name(repo_name=repo_name)
             if not result:
                 return result, message, latest_previous_version
 
-            find_string = json_data[len(json_data)-2].get('ref').split('/')
-            latest_previous_version = find_string[len(find_string)-1]
+            latest_previous_version = json_data[1].get('name')
 
             logging.info(f'Latest previous version of operadriver: {latest_previous_version}')
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
         return result_run, message_run , latest_previous_version
 
-    def __download_driver(self, version : str = '', previous_version : bool = False):
-        """Download specific version of phantomjs to folder
+    def __check_if_version_is_valid(self, url : str, version_url : str) -> Tuple[bool, str]:
+        """Checks the specified version for existence.
+
+        Args:
+            url (str)           : Full download url of operadriver.
+            version_url (str)   : Version that will be downloaded.
+
+        Returns:
+            Tuple of bool and str
+
+            result_run (bool)       : True if function passed correctly, False otherwise.
+            message_run (str)       : Returns an error message if an error occurs in the function.
+        """
+        result_run : bool = False
+        message_run : str = ''
+        archive_name : str = url.split("/")[len(url.split("/"))-1]
+        is_found : bool = False
+
+        try:
+
+            result, message, json_data = self.github_viewer.get_all_releases_data_by_repo_name(OperaDriver._repo_name)
+            if not result:
+                logging.error(message)
+                return result, message
+
+            for data in json_data:
+                if data.get('tag_name') == version_url or data.get('name') == version_url:
+                    for asset in data.get('assets'):
+                        if asset.get('name') == archive_name:
+                            is_found = True
+                            break
+
+            if not is_found:
+                message = f'Wrong version or system_name was specified. version_url: {version_url} url: {url}'
+                logging.error(message)
+                return False, message
+
+            result_run = True
+
+        except Exception:
+            message_run = f'Unexcepted error: {traceback.format_exc()}'
+            logging.error(message_run)
+
+        return result_run, message_run
+
+    def __download_driver(self, version : str = '', previous_version : bool = False) -> Tuple[bool, str, str]:
+        """Function to download, delete or upgrade current operadriver
+
+        Args:
+            version (str)               : Specific operadriver version to download. Defaults to empty string.
+            previous_version (boll)     : If true, operadriver latest previous version will be downloaded. Defaults to False.
 
         Returns:
             Tuple of bool, str and str
 
             result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
-            file_name (str)         : File name of unzipped file
-            
+            message_run (str)       : Returns an error message if an error occurs in the function.
+            driver_path (str)       : Path to unzipped driver.
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
         result_run : bool = False
         message_run : str = ''
-        file_name : str = ''
         url : str = ''
         latest_version : str = ''
+        latest_previous_version : str = ''
+
+        driver_path : str = ''
 
         try:
 
@@ -571,17 +570,12 @@ class OperaDriver():
                 result, message = self.__delete_current_operadriver_for_current_os()
                 if not result:
                     logging.error(message)
-                    return result, message, file_name
+                    return result, message, driver_path
 
             if version:
 
-                latest_version_url = "v." + version 
-                url = self.setting["OperaDriver"]["LinkLastReleasePlatform"].format(latest_version_url, latest_version_url)
-                result, message, status_code, json_data = self.requests_getter.get_result_by_request(url=url, return_text=False)
-                if not result:
-                    logging.error(message)
-                    return result, message, file_name
-                
+                url = self.setting["OperaDriver"]["LinkLastReleasePlatform"].format(version, version)
+
                 logging.info(f'Started download operadriver specific_version: {version}')
 
             elif previous_version:
@@ -589,10 +583,10 @@ class OperaDriver():
                 result, message, latest_previous_version = self.__get_latest_previous_version_operadriver_via_requests()
                 if not result:
                     logging.error(message)
-                    return result, message, file_name
+                    return result, message, driver_path
 
                 url = self.setting["OperaDriver"]["LinkLastReleasePlatform"].format(latest_previous_version, latest_previous_version)
-                
+
                 logging.info(f'Started download operadriver latest_previous_version: {latest_previous_version}')
 
             else:
@@ -600,71 +594,85 @@ class OperaDriver():
                 result, message, latest_version = self.__get_latest_version_operadriver()
                 if not result:
                     logging.error(message)
-                    return result, message, file_name
+                    return result, message, driver_path
+
+                url = self.setting["OperaDriver"]["LinkLastReleasePlatform"].format(latest_version, latest_version)
 
-                latest_version_url = "v." + latest_version
-                url = self.setting["OperaDriver"]["LinkLastReleasePlatform"].format(latest_version_url, latest_version_url)
-                
                 logging.info(f'Started download operadriver latest_version: {latest_version}')
 
+            if self.system_name:
+                url = url.replace(url.split("/")[len(url.split("/"))-1], '')
+                url = url + self.system_name
+
+                logging.info(f'Started downloading chromedriver for specific system: {self.system_name}')
+
+            if any([version, self.system_name ,latest_previous_version]):
+                version_url = version if version else latest_previous_version if latest_previous_version else latest_version
+                result, message = self.__check_if_version_is_valid(url=url, version_url=version_url)
+                if not result:
+                    logging.error(message)
+                    return result, message, driver_path
+
             archive_name = url.split("/")[len(url.split("/"))-1]
             out_path = self.path + archive_name
 
-            if os.path.exists(out_path):
-                os.remove(out_path)
+            if Path(out_path).exists():
+                Path(out_path).unlink()
 
             logging.info(f'Started download operadriver by url: {url}')
 
             if self.info_messages:
-                file_name = wget.download(url=url, out=out_path)
+                archive_path = wget.download(url=url, out=out_path)
             else:
-                file_name = wget.download(url=url, out=out_path, bar=None)
+                archive_path = wget.download(url=url, out=out_path, bar=None)
 
-            logging.info(f'Operadriver was downloaded to path: {file_name}')
+            logging.info(f'Operadriver was downloaded to path: {archive_path}')
 
             time.sleep(2)
 
-            archive_path = file_name
             out_path = self.path
-            result, message = self.extractor.extract_all_zip_archive(archive_path=archive_path, out_path=out_path)
+            result, message = self.extractor.extract_and_detect_archive_format(archive_path=archive_path, out_path=out_path)
             if not result:
                 logging.error(message)
-                return result, message, file_name
+                return result, message, driver_path
 
-            archive_folder_path = self.path + self.setting["OperaDriver"]["NamePlatformRelease"]
-            archive_operadriver_path = archive_folder_path + os.path.sep + self.setting['OperaDriver']['LastReleasePlatform']
+            platform : str = self.setting['OperaDriver']['LastReleasePlatform'] if not self.specific_driver_name else self.specific_driver_name
+
+            archive_folder_path = self.path + Path(archive_path).stem + os.path.sep
+            archive_operadriver_path = archive_folder_path + platform
 
             if not self.filename:
-
-                copyfile(archive_operadriver_path, self.path + self.setting['OperaDriver']['LastReleasePlatform'])
+                
+                copyfile(archive_operadriver_path, self.path + platform)
 
             else:
 
                 result, message = self.__rename_driver(archive_folder_path=archive_folder_path,
                                                         archive_operadriver_path=archive_operadriver_path)
                 if not result:
-                    return result, message, file_name
+                    return result, message, driver_path
 
-            if os.path.exists(file_name):
-                os.remove(file_name)
+            if Path(archive_path).exists():
+                Path(archive_path).unlink()
 
-            if os.path.exists(archive_folder_path):
+            if Path(archive_folder_path).exists():
                 shutil.rmtree(archive_folder_path)
-            
-            file_name = self.operadriver_path
 
-            logging.info(f'Operadriver was successfully unpacked by path: {file_name}')
+            driver_path = self.operadriver_path
+
+            logging.info(f'Operadriver was successfully unpacked by path: {driver_path}')
 
             if self.chmod:
 
                 result, message = self.__chmod_driver()
                 if not result:
-                    return result, message, file_name
+                    return result, message, driver_path
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
-        return result_run, message_run, file_name
\ No newline at end of file
+        return result_run, message_run, driver_path
+        
\ No newline at end of file
