@@ -1,70 +1,78 @@
+#Standart library imports
 import shutil
 import subprocess
-import wget
 import os
 import traceback
 import logging
 import time
 import stat
-import os
-
 import platform
+from typing import Tuple, Any
+from pathlib import Path
+import re
+from shutil import copyfile
+import wget
 
-from typing import Tuple
-
-import sys
-import os.path
-sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__))))
-
+# Local imports
 from _setting import setting
 
-from selenium import webdriver
-
-from selenium.common.exceptions import SessionNotCreatedException
-from selenium.common.exceptions import WebDriverException
-
 from util.extractor import Extractor
 from util.github_viewer import GithubViewer
 from util.requests_getter import RequestsGetter
 
-import pathlib
-
-import re
-
-from shutil import copyfile
-
 class PhantomJS():
-
+    "Class for working with Selenium phantomjs binary"
 
     _repo_name = 'ariya/phantomjs'
     _tmp_folder_path = 'tmp'
-    
-    def __init__(self, path : str, **kwargs):
-        """Class for working with Selenium phantomjs binary
 
-        Args:
-            path (str)                          : Specified path which will used for downloading or updating Selenium phantomjs binary. Must be folder path.
-            upgrade (bool)                      : If true, it will overwrite existing driver in the folder. Defaults to False.
-            chmod (bool)                        : If true, it will make phantomjs binary executable. Defaults to True.
-            check_driver_is_up_to_date (bool)   : If true, it will check driver version before and after upgrade. Defaults to False.
-            filename (str)                      : Specific name for phantomjs. If given, it will replace name for phantomjs.
-            version (str)                       : Specific version for phantomjs. If given, it will downloads given version.
-        """
-        self.setting = setting
+    def __init__(self, **kwargs):
+
+        self.setting : Any = setting
+
+        self.path : str = str(kwargs.get('path'))
 
-        self.path : str = path
-                    
         self.upgrade : bool = bool(kwargs.get('upgrade'))
 
         self.chmod : bool = bool(kwargs.get('chmod'))
 
         self.check_driver_is_up_to_date : bool = bool(kwargs.get('check_driver_is_up_to_date'))
-        
-        specific_filename = str(kwargs.get('filename'))
-        self.filename = f"{specific_filename}.exe" if platform.system() == 'Windows' and specific_filename else\
-                        specific_filename
 
-        self.phantomjs_path : str =  self.path + self.setting["PhantomJS"]["LastReleasePlatform"] if not specific_filename else self.path + self.filename
+        self.specific_driver_name = ''
+        self.system_name = ''
+
+        specific_filename = str(kwargs.get('filename'))
+
+        specific_system = str(kwargs.get('system_name', ''))
+        specific_system = specific_system.replace('linux64', 'linux-x86_64').replace('linux', 'linux-x86_64')
+        specific_system = specific_system.replace('linux32', 'linux-i686').replace('macos', 'macosx')
+
+        if specific_system:
+            self.system_name = "phantomjs-{}-" + f"{specific_system}"
+            if 'win' in specific_system:
+                self.system_name = "phantomjs-{}-windows"
+
+            if 'linux' in specific_system:
+                self.system_name = self.system_name + '.tar.bz2'
+            else:
+                self.system_name = self.system_name + '.zip'
+
+            self.filename = f"{specific_filename}.exe" if 'windows' in specific_system and specific_filename else\
+                            specific_filename
+
+            self.specific_driver_name =    "phantomjs.exe" if 'windows' in specific_system else\
+                                        "phantomjs"
+
+            name = self.specific_driver_name
+
+        else:
+
+            self.filename = f"{specific_filename}.exe" if platform.system() == 'Windows' and specific_filename else\
+                            specific_filename
+
+            name = self.setting["PhantomJS"]["LastReleasePlatform"]
+
+        self.phantomjs_path : str =  self.path + name if not specific_filename else self.path + self.filename
 
         self.version = str(kwargs.get('version'))
 
@@ -75,74 +83,6 @@ class PhantomJS():
         self.requests_getter = RequestsGetter
 
     def __get_current_version_phantomjs(self) -> Tuple[bool, str, str]:
-        """Gets current phantomjs version
-
-
-        Returns:
-            Tuple of bool, str and str
-
-            result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
-            driver_version (str)    : Current driver version.
-
-        Raises:
-            SessionNotCreatedException: Occurs when current phantomjs could not start.
-
-            WebDriverException: Occurs when current phantomjs could not start or critical error occured
-
-            OSError: Occurs when phantomjs made for another CPU type
-
-            Except: If unexpected error raised. 
-
-        """
-
-        result_run : bool = False
-        message_run : str = ''
-        driver_version : str = ''
-
-        try:
-
-            if os.path.exists(self.phantomjs_path):
-
-                result, message, driver_version = self.__get_current_version_phantomjs_via_terminal()
-                if not result:
-                    logging.error(message)
-                    message = 'Trying to get current version of phantomjs via webdriver'
-                    logging.info(message)
-                
-                if not True or not driver_version:
-
-                    driver = webdriver.PhantomJS(executable_path = self.phantomjs_path)
-                    driver_version = str(driver.capabilities['version'])
-                    driver.close()
-                    driver.quit()
-        
-                logging.info(f'Current version of phantomjs: {driver_version}')
-
-            result_run = True
-
-        except SessionNotCreatedException:
-            message_run = f'SessionNotCreatedException error: {traceback.format_exc()}'
-            logging.error(message_run)
-            return True, message_run, driver_version
-
-        except WebDriverException:
-            message_run = f'WebDriverException error: {traceback.format_exc()}'
-            logging.error(message_run)
-            return True, message_run, driver_version
-
-        except OSError:
-            message_run = f'OSError error: {traceback.format_exc()}' #probably [Errno 86] Bad CPU type in executable:
-            logging.error(message_run)
-            return True, message_run, driver_version
-
-        except:
-            message_run = f'Unexcepted error: {traceback.format_exc()}'
-            logging.error(message_run)
-        
-        return result_run, message_run, driver_version
-
-    def __get_current_version_phantomjs_via_terminal(self) -> Tuple[bool, str, str]:
         """Gets current phantomjs version via command in terminal
 
 
@@ -155,7 +95,9 @@ class PhantomJS():
 
         Raises:
 
-            Except: If unexpected error raised. 
+            OSError: Occurs when chromedriver made for another CPU type
+
+            Except: If unexpected error raised.
 
         """
 
@@ -163,24 +105,30 @@ class PhantomJS():
         message_run : str = ''
         driver_version : str = ''
         driver_version_terminal : str = ''
-        
-        try:
-            
-            logging.info('Trying to get current version of phantomjs via terminal')
-        
-            process = subprocess.Popen([self.phantomjs_path, '--version'], stdout=subprocess.PIPE)
-    
-            driver_version_terminal = process.communicate()[0].decode('UTF-8')
 
-            find_string = re.findall(self.setting["GeckoDriver"]["geckodriverVersionPattern"], driver_version_terminal)
-            driver_version = find_string[0] if len(find_string) > 0 else ''
+        try:
+
+            if Path(self.phantomjs_path).exists():
+
+                with subprocess.Popen([self.phantomjs_path, '--version'], stdout=subprocess.PIPE) as process:
+                    driver_version_terminal = process.communicate()[0].decode('UTF-8')
+
+                find_string = re.findall(self.setting["Program"]["wedriverVersionPattern"], driver_version_terminal)
+                driver_version = find_string[0] if len(find_string) > 0 else ''
+
+                logging.info(f'Current version of phantomjs: {driver_version}')
 
             result_run = True
 
-        except:
+        except OSError:
+            message_run = f'OSError error: {traceback.format_exc()}' #probably [Errno 86] Bad CPU type in executable:
+            logging.error(message_run)
+            return True, message_run, driver_version
+
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
-        
+
         return result_run, message_run, driver_version
 
     def __get_latest_version_phantomjs(self) -> Tuple[bool, str, str]:
@@ -193,9 +141,9 @@ class PhantomJS():
             result_run (bool)       : True if function passed correctly, False otherwise.
             message_run (str)       : Empty string if function passed correctly, non-empty string if error.
             latest_version (str)    : Latest version of phantomjs.
-            
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
@@ -204,13 +152,13 @@ class PhantomJS():
         latest_version : str = ''
 
         try:
-            
+
             repo_name = PhantomJS._repo_name
             result, message, json_data = self.github_viewer.get_latest_release_tag_by_repo_name(repo_name=repo_name)
             if not result:
                 return result, message, latest_version
 
-            find_string = re.findall(self.setting["GeckoDriver"]["geckodriverVersionPattern"], json_data.get('ref'))
+            find_string = re.findall(self.setting["Program"]["wedriverVersionPattern"], json_data.get('ref'))
             latest_version = find_string[0] if len(find_string) > 0 else ''
 
             if not latest_version:
@@ -222,7 +170,7 @@ class PhantomJS():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
@@ -237,9 +185,9 @@ class PhantomJS():
             result_run (bool)           : True if function passed correctly, False otherwise.
             message_run (str)           : Empty string if function passed correctly, non-empty string if error.
             is_driver_up_to_date (bool) : If true current version of phantomjs is up to date. Defaults to False.
-            
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
         result_run : bool = False
@@ -247,14 +195,14 @@ class PhantomJS():
         is_driver_up_to_date : bool = False
         current_version : str = ''
         latest_version : str = ''
-        
+
         try:
 
             result, message, current_version = self.__get_current_version_phantomjs()
             if not result:
                 logging.error(message)
                 return result, message, is_driver_up_to_date, current_version, latest_version
-            
+
             if not current_version:
                 return True, message_run, is_driver_up_to_date, current_version, latest_version
 
@@ -270,7 +218,7 @@ class PhantomJS():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
@@ -285,18 +233,18 @@ class PhantomJS():
             result_run (bool)       : True if function passed correctly, False otherwise.
             message_run (str)       : Empty string if function passed correctly, non-empty string if error.
             driver_path (str)       : Path where phantomjs was downloaded or updated.
-            
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
         result_run : bool = False
         message_run : str = ''
         driver_path : str = ''
-        
+
         try:
 
-            if self.check_driver_is_up_to_date:
+            if self.check_driver_is_up_to_date and not self.system_name:
 
                 result, message, is_driver_up_to_date, current_version, latest_version = self.__compare_current_version_and_latest_version_phantomjs()
                 if not result:
@@ -310,8 +258,8 @@ class PhantomJS():
             if not result:
                 logging.error(message)
                 return result, message, driver_path
-            
-            if self.check_driver_is_up_to_date:
+
+            if self.check_driver_is_up_to_date and not self.system_name:
 
                 result, message, is_driver_up_to_date, current_version, latest_version = self.__compare_current_version_and_latest_version_phantomjs()
                 if not result:
@@ -331,7 +279,7 @@ class PhantomJS():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
@@ -346,9 +294,9 @@ class PhantomJS():
 
             result_run (bool)       : True if function passed correctly, False otherwise.
             message_run (str)       : Empty string if function passed correctly, non-empty string if error.
-            
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
@@ -357,15 +305,14 @@ class PhantomJS():
 
         try:
 
-            if os.path.exists(self.phantomjs_path):
-                
+            if Path(self.phantomjs_path).exists():
+
                 logging.info(f'Deleted existing phantomjs phantomjs_path: {self.phantomjs_path}')
-                file_to_rem = pathlib.Path(self.phantomjs_path)
-                file_to_rem.unlink()
+                Path(self.phantomjs_path).unlink()
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
@@ -379,17 +326,17 @@ class PhantomJS():
 
             result_run (bool)           : True if function passed correctly, False otherwise.
             message_run (str)           : Empty string if function passed correctly, non-empty string if error.
-            
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
         result_run : bool = False
         message_run : str = ''
-        
+
         try:
 
-            if os.path.exists(self.phantomjs_path):
+            if Path(self.phantomjs_path).exists():
 
                 logging.info('Trying to give phantomjs needed permissions')
 
@@ -400,7 +347,7 @@ class PhantomJS():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
@@ -418,38 +365,38 @@ class PhantomJS():
 
             result_run (bool)           : True if function passed correctly, False otherwise.
             message_run (str)           : Empty string if function passed correctly, non-empty string if error.
-            
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
         result_run : bool = False
         message_run : str = ''
         renamed_driver_path : str = ''
-        
+
         try:
 
             new_path = archive_folder_path + os.path.sep + self.filename if not archive_folder_path.endswith(os.path.sep) else archive_folder_path + self.filename
 
-            if os.path.exists(new_path):
-                os.remove(new_path)
+            if Path(new_path).exists():
+                Path(new_path).unlink()
 
             os.rename(archive_driver_path, new_path)
-            
+
             renamed_driver_path = self.path + self.filename
-            if os.path.exists(renamed_driver_path):
-                os.remove(renamed_driver_path)
+            if Path(renamed_driver_path).exists():
+                Path(renamed_driver_path).unlink()
 
             copyfile(new_path, renamed_driver_path)
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
         return result_run, message_run
-    
+
     def main(self) -> Tuple[bool, str, str]:
         """Main function, checks for the latest version, downloads or updates phantomjs binary or
         downloads specific version of phantomjs.
@@ -460,15 +407,15 @@ class PhantomJS():
             result_run (bool)       : True if function passed correctly, False otherwise.
             message_run (str)       : Empty string if function passed correctly, non-empty string if error.
             driver_path (str)       : Path where phantomjs was downloaded or updated.
-            
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
         result_run : bool = False
         message_run : str = ''
         driver_path : str = ''
-        
+
         try:
 
             if not self.version:
@@ -487,7 +434,7 @@ class PhantomJS():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
@@ -503,9 +450,9 @@ class PhantomJS():
             result_run (bool)               : True if function passed correctly, False otherwise.
             message_run (str)               : Empty string if function passed correctly, non-empty string if error.
             latest_version_previous (str)   : Latest previous version of phantomjs.
-            
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
@@ -527,7 +474,7 @@ class PhantomJS():
                 value_name = value.get('name')
                 if not 'beta' in value_name:
 
-                    find_string = re.findall(self.setting["GeckoDriver"]["geckodriverVersionPattern"], value_name)
+                    find_string = re.findall(self.setting["Program"]["wedriverVersionPattern"], value_name)
                     version = find_string[0] if len(find_string) > 0 else ''
 
                     all_versions.append(version)
@@ -541,31 +488,87 @@ class PhantomJS():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
         return result_run, message_run, latest_previous_version
 
-    def __download_driver(self, version : str = '', previous_version : bool = False):
-        """Download specific version of phantomjs to folder
+    def __check_if_version_is_valid(self, url : str) -> Tuple[bool, str]:
+        """Checks the specified version for existence.
+
+        Args:
+            url (str) : Full download url of chromedriver.
+
+        Returns:
+            Tuple of bool and str
+
+            result_run (bool)       : True if function passed correctly, False otherwise.
+            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
+        """
+        result_run : bool = False
+        message_run : str = ''
+        archive_name : str = url.split("/")[len(url.split("/"))-1]
+        url_releases : str = self.setting["PhantomJS"]["LinkAllReleases"]
+        is_found : bool = False
+
+        try:
+
+            while is_found == False:
+
+                result, message, status_code, json_data = self.requests_getter.get_result_by_request(url=url_releases, is_json=True)
+                if not result:
+                    logging.error(message)
+                    return result, message
+
+                for data in json_data.get('values'):
+                    if data.get('name') == archive_name:
+                        is_found = True
+                        break
+
+                url_releases = json_data.get('next')
+                if not url_releases:
+                    break
+
+            if not is_found:
+                message = f'Wrong version or system_name was specified. archive_name: {archive_name} url: {url}'
+                logging.error(message)
+                return False, message
+
+            result_run = True
+
+        except Exception:
+            message_run = f'Unexcepted error: {traceback.format_exc()}'
+            logging.error(message_run)
+
+        return result_run, message_run
+
+    def __download_driver(self, version : str = '', previous_version : bool = False) -> Tuple[bool, str, str]:
+        """Function to download, delete or upgrade current phantomjs
+
+        Args:
+            version (str)               : Specific phantomjs version to download. Defaults to empty string.
+            previous_version (boll)     : If true, phantomjs latest previous version will be downloaded. Defaults to False.
 
         Returns:
             Tuple of bool, str and str
 
             result_run (bool)       : True if function passed correctly, False otherwise.
             message_run (str)       : Empty string if function passed correctly, non-empty string if error.
-            file_name (str)         : File name of unzipped file
-            
+            driver_path (str)       : Path to unzipped driver.
+
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
         result_run : bool = False
         message_run : str = ''
-        file_name : str = ''
         url : str = ''
+        latest_version : str = ''
+        latest_previous_version : str = ''
+
+        driver_path : str = ''
 
         try:
 
@@ -574,29 +577,20 @@ class PhantomJS():
                 result, message = self.__delete_current_phantomjs_for_current_os()
                 if not result:
                     logging.error(message)
-                    return result, message, file_name
-            
+                    return result, message, driver_path
+
             if version:
 
-                logging.info(f'Started download phantomjs: {version}')
+                logging.info(f'Started download phantomjs specific_version: {version}')
 
                 url = self.setting["PhantomJS"]["LinkLastReleaseFile"].format(version)
-                result, message, status_code, json_data = self.requests_getter.get_result_by_request(url=url, return_text = False, no_error_status_code=True)
-                if not result:
-                    logging.error(message)
-                    return result, message, file_name
-
-                if status_code != 200:
-                    message = f'Specific binary was not found, wrong version was specified. version: {version}'
-                    logging.error(message)
-                    return result_run, message, file_name
 
             elif previous_version:
 
                 result, message, latest_previous_version = self.__get_latest_previous_version_phantomjs_via_requests()
                 if not result:
                     logging.error(message)
-                    return result, message, file_name
+                    return result, message, driver_path
 
                 logging.info(f'Started download phantomjs latest_previous_version: {latest_previous_version}')
 
@@ -606,92 +600,86 @@ class PhantomJS():
                 result, message, latest_version = self.__get_latest_version_phantomjs()
                 if not result:
                     logging.error(message)
-                    return result, message, file_name
+                    return result, message, driver_path
 
                 logging.info(f'Started download phantomjs latest_version: {latest_version}')
 
                 url = self.setting["PhantomJS"]["LinkLastReleaseFile"].format(latest_version)
 
+            if self.system_name:
+                url = url.replace(url.split("/")[len(url.split("/"))-1], '')
+                url = url + self.system_name.format(latest_version) if latest_version else url + self.system_name.format(latest_previous_version) if latest_previous_version else\
+                url + self.system_name.format(version)
+
+                logging.info(f'Started downloading geckodriver for specific system: {self.system_name}')
+
+            if any([version, self.system_name ,latest_previous_version]):
+
+                result, message = self.__check_if_version_is_valid(url=url)
+                if not result:
+                    logging.error(message)
+                    return result, message, driver_path
+
             archive_name = url.split("/")[len(url.split("/"))-1]
             out_path = self.path + archive_name
 
-            if os.path.exists(out_path):
-                os.remove(out_path)
+            if Path(out_path).exists():
+                Path(out_path).unlink()
 
             logging.info(f'Started download phantomjs by url: {url}')
 
             if self.info_messages:
-                file_name = wget.download(url=url, out=out_path)
+                archive_path = wget.download(url=url, out=out_path)
             else:
-                file_name = wget.download(url=url, out=out_path, bar=None)
+                archive_path = wget.download(url=url, out=out_path, bar=None)
             time.sleep(2)
 
-            logging.info(f'PhantomJS was downloaded to path: {file_name}')
+            logging.info(f'PhantomJS was downloaded to path: {archive_path}')
 
-            if file_name.endswith('.zip'):
+            out_path = self.path
 
-                archive_path = file_name
-                out_path = self.path
-                result, message = self.extractor.extract_all_zip_archive(archive_path=archive_path, out_path=out_path)
-                if not result:
-                    logging.error(message)
-                    return result, message, file_name
+            parameters = dict(archive_path=archive_path, out_path=out_path)
 
-            elif file_name.endswith('.tar.bz2'):
-
-                archive_path = file_name
-                out_path = self.path
-                result, message = self.extractor.extract_all_tar_bz2_archive(archive_path=archive_path, out_path=out_path)
-                if not result:
-                    logging.error(message)
-                    return result, message, file_name
-
-            elif file_name.endswith('.tar.gz'):
-
-                archive_path = file_name
-                out_path = self.path
-                result, message = self.extractor.extract_all_tar_gz_archive(archive_path=archive_path, out_path=out_path)
-                if not result:
-                    logging.error(message)
-                    return result, message, file_name
-
-            else:
-                message = f'Unknown archive format was specified file_name: {file_name}'
+            result, message = self.extractor.extract_and_detect_archive_format(**parameters)
+            if not result:
                 logging.error(message)
-                return result_run, message, file_name
+                return result, message, driver_path
 
-            archive_path_folder = self.path + url.split('/')[6].replace('.zip', '').replace(".tar.bz2", '') + os.path.sep
+            platform : str = self.setting["PhantomJS"]["LastReleasePlatform"] if not self.specific_driver_name else self.specific_driver_name 
+
+            archive_path_folder = self.path + url.split('/')[len(url.split('/'))-1].replace('.zip', '').replace(".tar.bz2", '') + os.path.sep
             archive_path_folder_bin = archive_path_folder + 'bin' +  os.path.sep
-            driver_archive_path = archive_path_folder_bin + self.setting["PhantomJS"]["LastReleasePlatform"]
+            driver_archive_path = archive_path_folder_bin + platform
 
             if not self.filename:
 
-                copyfile(driver_archive_path, self.path + self.setting["PhantomJS"]["LastReleasePlatform"])
+                copyfile(driver_archive_path, self.path + platform)
 
             else:
 
-                result, message = self.__rename_driver(archive_folder_path=archive_path_folder_bin, archive_driver_path=driver_archive_path)
+                parameters = dict(archive_folder_path=archive_path_folder_bin, archive_driver_path=driver_archive_path)
+                result, message = self.__rename_driver(**parameters)
                 if not result:
                     logging.error(message)
-                    return result, message, file_name
+                    return result, message, driver_path
 
-            if os.path.exists(archive_path_folder):
+            if Path(archive_path_folder).exists():
                 shutil.rmtree(archive_path_folder)
             
-            file_name = self.phantomjs_path
+            driver_path = self.phantomjs_path
 
-            logging.info(f'PhantomJS was successfully unpacked by path: {file_name}')
+            logging.info(f'PhantomJS was successfully unpacked by path: {driver_path}')
 
             if self.chmod:
 
                 result, message = self.__chmod_driver()
                 if not result:
-                    return result, message, file_name
+                    return result, message, driver_path
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
-        return result_run, message_run, file_name
\ No newline at end of file
+        return result_run, message_run, driver_path
