@@ -16,17 +16,17 @@ chromedriver_platform_release = "chromedriver.exe" if platform.system() == 'Wind
                                 "chromedriver"
 
 
-latest_release_geckodriver = 'https://github.com/mozilla/geckodriver/releases/download/{}/'
-geckodriver_platform_release =  latest_release_geckodriver + "geckodriver-{}-" + f"win{os_bit}.zip" if platform.system() == 'Windows' else\
-                                latest_release_geckodriver + "geckodriver-{}-" + f"linux{os_bit}.tar.gz" if platform.system() == "Linux" else\
-                                latest_release_geckodriver + "geckodriver-{}-macos-aarch64.tar.gz" if 'arm' in str(os.uname().machine) and platform.system() == 'Darwin' else\
-                                latest_release_geckodriver + "geckodriver-{}-macos.tar.gz"
+latest_release_geckodriver = 'https://github.com/mozilla/geckodriver/releases/download/v{}/'
+geckodriver_platform_release =  latest_release_geckodriver + "geckodriver-v{}-" + f"win{os_bit}.zip" if platform.system() == 'Windows' else\
+                                latest_release_geckodriver + "geckodriver-v{}-" + f"linux{os_bit}.tar.gz" if platform.system() == "Linux" else\
+                                latest_release_geckodriver + "geckodriver-v{}-macos-aarch64.tar.gz" if 'arm' in str(os.uname().machine) and platform.system() == 'Darwin' else\
+                                latest_release_geckodriver + "geckodriver-v{}-macos.tar.gz"
 
 geckodriver_platform_last_release = "geckodriver.exe" if platform.system() == 'Windows' else\
                                 "geckodriver"
 
 
-latest_release_operadriver = 'https://github.com/operasoftware/operachromiumdriver/releases/download/{}/'
+latest_release_operadriver = 'https://github.com/operasoftware/operachromiumdriver/releases/download/v.{}/'
 operadriver_latest_release =    latest_release_operadriver + f"operadriver_win{os_bit}.zip" if platform.system() == 'Windows' else\
                                 latest_release_operadriver + "operadriver_linux64.zip" if platform.system() == "Linux" else\
                                 latest_release_operadriver + "operadriver_mac64.zip"
@@ -49,7 +49,7 @@ edgedriver_latest_release =     latest_release_edgedriver + f"edgedriver_win{os_
 edgedriver_platform_release =  "msedgedriver.exe" if platform.system() == 'Windows' else\
                              "msedgedriver"
 
-url_release_phantomjs = "https://bitbucket.org/ariya/phantomjs/downloads/"
+url_release_phantomjs = "https://api.bitbucket.org/2.0/repositories/ariya/phantomjs/downloads/"
 os_bit_linux = 'x86_64' if os_bit == '64' else "i686"
 phantomjs_latest_release =      url_release_phantomjs + "phantomjs-{}-windows.zip" if platform.system() == 'Windows' else\
                                 url_release_phantomjs + "phantomjs-{}-linux-{}.tar.bz2".format({}, os_bit_linux) if platform.system() == "Linux" else\
@@ -64,10 +64,11 @@ phantomjs_platform_release = "phantomjs.exe" if platform.system() == 'Windows' e
 #                                 
 
 chrome_browser_path = '/Applications/Google Chrome.app/Contents/MacOS/Google Chrome' if platform.system() == 'Darwin' else \
-'reg query "HKEY_CURRENT_USER\Software\Google\Chrome\BLBeacon" /v version' if platform.system() == 'Windows' else \
+['reg query "HKEY_CURRENT_USER\Software\Google\Chrome\BLBeacon" /v version',
+r'reg query "HKEY_LOCAL_MACHINE\SOFTWARE\WOW6432Node\Microsoft\Windows\CurrentVersion\Uninstall\Google Chrome" /v version'] if platform.system() == 'Windows' else \
 "google-chrome-stable" if platform.system() == 'Linux' else ''
 
-chrome_browser_updater = fr'"C:\Program Files (x86)\Google\Update\GoogleUpdate.exe"' if platform.system() == 'Windows' else \
+chrome_browser_updater = r'"C:\Program Files (x86)\Google\Update\GoogleUpdate.exe"' if platform.system() == 'Windows' else \
 'open "/Library/Google/GoogleSoftwareUpdate/GoogleSoftwareUpdate.bundle/Contents/Helpers/GoogleSoftwareUpdateAgent.app"' if platform.system() == 'Darwin' else\
 "sudo apt-get install google-chrome-stable" if platform.system() == 'Linux' else ''
 
@@ -90,16 +91,16 @@ firefox_browser_updater_path = r"C:\Program Files\Mozilla Firefox\updater.exe" i
 
 
 edge_browser_path = '/Applications/Microsoft Edge.app/Contents/MacOS/Microsoft Edge' if platform.system() == 'Darwin' else\
-'reg query "HKEY_USERS\S-1-5-21-3790059719-4236911619-2548269985-1000\Software\Microsoft\Edge\BLBeacon" /v version' if platform.system() == 'Windows' else ''
+'reg query "HKEY_CURRENT_USER\SOFTWARE\Microsoft\Edge\BLBeacon" /v version' if platform.system() == 'Windows' else ''
 
-edge_browser_updater = fr'"C:\Program Files (x86)\Microsoft\EdgeUpdate\MicrosoftEdgeUpdate.exe"' if platform.system() == 'Windows' else \
+edge_browser_updater = r'"C:\Program Files (x86)\Microsoft\EdgeUpdate\MicrosoftEdgeUpdate.exe"' if platform.system() == 'Windows' else \
 'open "/Library/Application Support/Microsoft/MAU2.0/Microsoft AutoUpdate.app/Contents/MacOS/Microsoft Update Assistant.app"' if platform.system() == 'Darwin' else ''
 
-edge_browser_updater_path = fr"C:\Program Files (x86)\Microsoft\EdgeUpdate\MicrosoftEdgeUpdate.exe" if platform.system() == 'Windows' else \
+edge_browser_updater_path = r"C:\Program Files (x86)\Microsoft\EdgeUpdate\MicrosoftEdgeUpdate.exe" if platform.system() == 'Windows' else \
 '/Library/Application Support/Microsoft/MAU2.0/Microsoft AutoUpdate.app/Contents/MacOS/Microsoft Update Assistant.app' if platform.system() == 'Darwin' else ''
 
 
-opera_browser_path = r'REG QUERY "HKEY_USERS\S-1-5-21-3790059719-4236911619-2548269985-1000\Software\Microsoft\Windows\CurrentVersion\Uninstall"' if platform.system() == 'Windows' else \
+opera_browser_path = r'reg query "HKEY_CURRENT_USER\Software\Microsoft\Windows\CurrentVersion\Uninstall" /f Opera' if platform.system() == 'Windows' else \
 '/Applications/Opera.app/Contents/MacOS/Opera' if platform.system() == 'Darwin' else\
 "opera" if platform.system() == 'Linux' else ''
 
@@ -116,15 +117,20 @@ chromiumbrowser_updater = "sudo apt-get install chromium-browser"
 
 chromiumchromedriver_updater = "sudo apt-get install chromedriver"
 
+from dataclasses import dataclass
+
+@dataclass
 class info:
-    version = "3.6.0"
+    version = "4.0.2"
 
 setting = dict(
     {
         "Program":
         {
             'version'                   : info.version,
-            'wedriverVersionPattern'    : '[0-9]+.[0-9]+.[0-9]+.[0-9]+',
+            'wedriverVersionPattern'    : r'([0-9.]*\.[0-9]+)',
+            'driversPath'               : base_dir + 'test' + os.path.sep + 'drivers' + os.path.sep,
+            'DriversFileFormat'         : ".exe" if platform.system() == 'Windows' else '',
         },
         "ChromeDriver":
         {   
@@ -132,26 +138,27 @@ setting = dict(
             "LinkLastReleaseFile"               : chromedriver_latest_release,
             "LastReleasePlatform"               : chromedriver_platform_release,
             "LinkLatestReleaseSpecificVersion"  : "https://chromedriver.storage.googleapis.com/LATEST_RELEASE_{}",
+            "LinkCheckVersionIsValid"           : "https://chromedriver.storage.googleapis.com/?delimiter=/&prefix={}/",
         },
         "GeckoDriver":
         {
             "LinkLastRelease"           : 'https://api.github.com/repos/mozilla/geckodriver/releases/latest',
             "LinkLastReleasePlatform"   : geckodriver_platform_release,
             "LastReleasePlatform"       : geckodriver_platform_last_release,
-            'geckodriverVersionPattern' : "[0-9]+.[0-9]+.[0-9]+",
         },
         "OperaDriver":
         {
             "LinkLastRelease"           : 'https://api.github.com/repos/operasoftware/operachromiumdriver/releases/latest',
             "LinkLastReleasePlatform"   : operadriver_latest_release, 
             "LastReleasePlatform"       : operadriver_platform_release, 
-            "NamePlatformRelease"       : operadriver_name_platform_release,
         },
         "EdgeDriver":
         {
-            "LinkLastRelease"           : 'https://developer.microsoft.com/en-us/microsoft-edge/tools/webdriver/',
-            "LinkLastReleaseFile"       : edgedriver_latest_release, 
-            "LastReleasePlatform"       : edgedriver_platform_release,
+            "LinkLastRelease"                   : 'https://msedgewebdriverstorage.blob.core.windows.net/edgewebdriver/LATEST_STABLE',
+            "LinkLastReleaseFile"               : edgedriver_latest_release, 
+            "LastReleasePlatform"               : edgedriver_platform_release,
+            "LinkCheckVersionIsValid"           : "https://msedgewebdriverstorage.blob.core.windows.net/edgewebdriver?prefix={}%2F&delimiter=%2F&maxresults=100&restype=container&comp=list&_=1622714933676&timeout=60000",
+            "LinkLatestReleaseSpecificVersion"  : "https://msedgewebdriverstorage.blob.core.windows.net/edgewebdriver/LATEST_RELEASE_{}",
         },
         "ChromiumChromeDriver":
         {
@@ -161,7 +168,7 @@ setting = dict(
         {   
             "LinkLastReleaseFile"   : phantomjs_latest_release,
             "LastReleasePlatform"   : phantomjs_platform_release,
-            "LinkAllReleases"       : 'https://api.bitbucket.org/2.0/repositories/ariya/phantomjs/downloads',
+            "LinkAllReleases"       : url_release_phantomjs,
         },
         "ChromeBrowser":
         {
@@ -207,10 +214,11 @@ setting = dict(
         {
             "linkLatestReleaseBySpecificRepoName"   : 'https://api.github.com/repos/{}/releases/latest',
             "linkAllReleasesTags"                   : 'https://api.github.com/repos/{}/git/refs/tags',
+            "linkAllReleases"                       : 'https://api.github.com/repos/{}/releases',
         },
         "PyPi":
         {
             'urlProjectJson'    : 'https://pypi.python.org/pypi/selenium-driver-updater/json',
         },
     }
-)
\ No newline at end of file
+)
