@@ -1,7 +1,17 @@
+#Standart library imports
+from dataclasses import dataclass
+from pathlib import Path
+import logging
+import os
+import traceback
+from typing import Tuple
+import time
+
 import sys
 import os.path
 sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__))))
 
+# Local imports
 from _chromeDriver import ChromeDriver
 from _geckoDriver import GeckoDriver
 from _operaDriver import OperaDriver
@@ -10,24 +20,51 @@ from _chromiumChromeDriver import ChromiumChromeDriver
 from _phantomJS import PhantomJS
 from _setting import setting
 
-import logging
-import os
-import traceback
-from typing import Tuple
-
-import time
-
 from util.requests_getter import RequestsGetter
 
+@dataclass
+class info():
+
+    _driver_name = ''
+
+    _path = ''
+    _filename = ''
+    _version = ''
+    _system_name = ''
+
+    _upgrade = False
+    _chmod = True
+    _check_driver_is_up_to_date = True
+    _info_messages = False
+
+    _check_browser_is_up_to_date = False
+    _enable_library_update_check = True
+
+#pylint: disable=protected-access
 class DriverUpdater():
 
+    #DRIVERS
     chromedriver = 'chromedriver'
     geckodriver = 'geckodriver'
     operadriver = 'operadriver'
     edgedriver = 'edgedriver'
-    chromium_chromedriver = 'chromium-chromedriver'
+    chromium_chromedriver = 'chromium_chromedriver'
     phantomjs = 'phantomjs'
-        
+
+    #OS'S
+    windows = 'win64'
+    windows32 = 'win32'
+    windows64 = 'win64'
+
+    linux = 'linux'
+    linux32 = 'linux32'
+    linux64 = 'linux64'
+
+    macos = 'mac64'
+    macos_m1 = 'mac64_m1'
+
+    arm = 'arm64'
+
     @staticmethod
     def install(driver_name, **kwargs):
         """Function for install or update Selenium driver binary
@@ -43,6 +80,7 @@ class DriverUpdater():
             version (str)                       : Specific version for chromedriver. If given, it will downloads given version. Defaults to empty string.
             check_browser_is_up_to_date (bool)  : If true, it will check browser version before specific driver update or upgrade. Defaults to False.
             enable_library_update_check (bool)  : If true, it will enable checking for library update while starting. Defaults to True.
+            system_name (Union[str, list[str]]) : Specific OS for driver. Defaults to empty string.
 
         Returns:
             Tuple of bool, str and str
@@ -52,7 +90,7 @@ class DriverUpdater():
             driver_path (str)       : Path where Selenium driver binary was downloaded or updated.
 
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
@@ -61,58 +99,68 @@ class DriverUpdater():
         message_run : str = ''
         driver_path = ''
 
-        info_messages = bool(kwargs.get('info_messages', True))
-        if info_messages:
+        info._driver_name = driver_name
+
+        info._info_messages = bool(kwargs.get('info_messages', True))
+
+        if info._info_messages:
             logging.basicConfig(level=logging.INFO)
         else:
             logging.basicConfig(level=logging.ERROR)
 
-        path = kwargs.get('path', sys.path[0])
-        logging.info('You have not specified the path - so used default folder path instead') if not kwargs.get('path') else ''
-        path = str(os.path.abspath(path) + os.path.sep)
+        path = kwargs.get('path')
+        if not path:
+            path = sys.path[0]
+            logging.info('You have not specified the path - so used default folder path instead')
 
-        filename : str = str(kwargs.get('filename', '')).replace('.', '') if type(kwargs.get('filename', '')) == str else\
+        info._path = str(os.path.abspath(path) + os.path.sep)
+
+        info._filename = str(kwargs.get('filename', '')).replace('.', '') if type(kwargs.get('filename', '')) == str else\
                          kwargs.get('filename', '') if type(kwargs.get('filename', '')) == list else ''
 
-        enable_library_update_check = bool(kwargs.get('enable_library_update_check', True))
-        upgrade = bool(kwargs.get('upgrade', False))
-        chmod = bool(kwargs.get('chmod', True))
-        check_driver_is_up_to_date = bool(kwargs.get('check_driver_is_up_to_date', False))
-        version = str(kwargs.get('version', ''))
-        check_browser_is_up_to_date = bool(kwargs.get('check_browser_is_up_to_date', False))
+        info._enable_library_update_check = bool(kwargs.get('enable_library_update_check', True))
+        info._upgrade = bool(kwargs.get('upgrade', False))
+        info._chmod = bool(kwargs.get('chmod', True))
+        info._check_driver_is_up_to_date = bool(kwargs.get('check_driver_is_up_to_date', False))
+
+        info._version = str(kwargs.get('version', '')) if type(kwargs.get('version', '')) == str else\
+                        kwargs.get('version', '') if type(kwargs.get('version', '')) == list else ''
+
+        info._check_browser_is_up_to_date = bool(kwargs.get('check_browser_is_up_to_date', False))
+
+        info._system_name = str(kwargs.get('system_name', '')) if type(kwargs.get('system_name', '')) == str else\
+                        kwargs.get('system_name', '') if type(kwargs.get('system_name', '')) == list else ''
 
         try:
 
-            result, message = DriverUpdater.__check_enviroment_and_variables(path=path, driver_name=driver_name, enable_library_update_check=enable_library_update_check, filename=filename)
+            result, message = DriverUpdater.__check_enviroment_and_variables()
             if not result:
                 logging.error(message)
                 return result, message, driver_path
 
-            if type(driver_name) == str:
+            if isinstance(info._driver_name, str):
 
-                result, message, driver_path = DriverUpdater.__run_specific_driver(driver_name=driver_name, path=path, upgrade=upgrade, chmod=chmod, 
-                                                check_driver_is_up_to_date=check_driver_is_up_to_date, 
-                                                filename=filename, version=version,
-                                                check_browser_is_up_to_date=check_browser_is_up_to_date, info_messages=info_messages)
+                result, message, driver_path = DriverUpdater.__run_specific_driver()
                 if not result:
                     logging.error(message)
                     return result, message, driver_path
 
-            elif type(driver_name) == list:
+            elif isinstance(info._driver_name, list):
 
                 list_of_paths : list[str] = []
-                
-                for driver in driver_name:
+
+                for driver in info._driver_name:
 
                     time.sleep(1) #small sleep
 
-                    filename_driver = str(filename[driver_name.index(driver)]) if len(filename) > driver_name.index(driver) and filename else ''
-                    filename_driver.replace('.', '')
+                    filename_driver = str(info._filename[info._driver_name.index(driver)]) if len(info._filename) > info._driver_name.index(driver) and info._filename else ''
+                    filename_driver = filename_driver.replace('.', '')
 
-                    result, message, driver_path = DriverUpdater.__run_specific_driver(driver_name=driver, path=path, upgrade=upgrade, chmod=chmod, 
-                                                check_driver_is_up_to_date=check_driver_is_up_to_date, 
-                                                filename=filename_driver, version=version,
-                                                check_browser_is_up_to_date=check_browser_is_up_to_date, info_messages=info_messages)
+                    system_name_driver = str(info._system_name[info._driver_name.index(driver)]) if len(info._system_name) > info._driver_name.index(driver) and info._system_name else ''
+
+                    version_driver = str(info._version[info._driver_name.index(driver)]) if len(info._version) > info._driver_name.index(driver) and info._version else ''
+
+                    result, message, driver_path = DriverUpdater.__run_specific_driver(driver_name=driver, filename=filename_driver, system_name=system_name_driver, version=version_driver)
                     if not result:
                         logging.error(message)
                         return result, message, driver_path
@@ -123,20 +171,16 @@ class DriverUpdater():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
         return result_run, message_run, driver_path
 
     @staticmethod
-    def __check_all_input_parameteres(path, driver_name, filename) -> Tuple[bool, str]:
+    def __check_all_input_parameteres() -> Tuple[bool, str]:
         """Private function for checking all input parameters
 
-        Args:
-            path (str)                          : Specified path which will used for downloading or updating Selenium driver binary. Must be folder path.
-            driver_name (Union[str, list[str]]) : Specified driver name/names which will be downloaded or updated. Like "DriverUpdater.chromedriver" or etc.
-
         Returns:
             Tuple of bool and str
 
@@ -144,7 +188,7 @@ class DriverUpdater():
             message_run (str)       : Empty string if function passed correctly, non-empty string if error.
 
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
         """
 
         result_run : bool = False
@@ -152,79 +196,81 @@ class DriverUpdater():
 
         try:
 
-            if not path:
-                message = f"Please specify path to folder current path is: {path}"
+            if not Path(info._path).exists():
+                message = f"The specified path does not exist current path is: {info._path}"
                 logging.error(message)
                 return result_run, message
 
-            if not os.path.exists(path):
-                message = f"The specified path does not exist current path is: {path}"
+            if not Path(info._path).is_dir():
+                message = f"The specified path is not a folder current path is: {info._path}"
                 logging.error(message)
                 return result_run, message
 
-            if not os.path.isdir(path):
-                message = f"The specified path is not a folder current path is: {path}"
-                logging.error(message)
-                return result_run, message
+            if isinstance(info._driver_name,(list, str)):
 
-            if type(driver_name) == str:
+                if info._filename:
 
-                driver_name_check =     DriverUpdater.chromedriver if DriverUpdater.chromedriver == driver_name else \
-                                        DriverUpdater.geckodriver  if DriverUpdater.geckodriver == driver_name else \
-                                        DriverUpdater.operadriver if DriverUpdater.operadriver == driver_name else \
-                                        DriverUpdater.edgedriver if DriverUpdater.edgedriver == driver_name else \
-                                        DriverUpdater.chromium_chromedriver if DriverUpdater.chromium_chromedriver == driver_name else \
-                                        DriverUpdater.phantomjs if DriverUpdater.phantomjs == driver_name else ''
-
-                if not driver_name_check:
-                    message = f'Unknown driver name was specified current driver_name is: {driver_name}'
-                    logging.error(message)
-                    return result_run, message
-
-                if filename:
-
-                    if type(filename) != str:
-                        message = f'Unknown type of filename was specificed type(filename): {type(filename)}, but must be str, if one driver is given'
+                    result, message = DriverUpdater.__check_parameter_type_is_valid(info._filename, type(info._driver_name), 'filename')
+                    if not result:
                         logging.error(message)
-                        return result_run, message
+                        return result, message
 
-            elif type(driver_name) == list:
+                if info._system_name:
 
-                for driver in driver_name:
-
-                    driver_name_list =      DriverUpdater.chromedriver if DriverUpdater.chromedriver == driver else \
-                                            DriverUpdater.geckodriver  if DriverUpdater.geckodriver == driver else \
-                                            DriverUpdater.operadriver if DriverUpdater.operadriver == driver else \
-                                            DriverUpdater.edgedriver if DriverUpdater.edgedriver == driver else \
-                                            DriverUpdater.chromium_chromedriver if DriverUpdater.chromium_chromedriver == driver else \
-                                            DriverUpdater.phantomjs if DriverUpdater.phantomjs == driver else ''
-
-                    if not driver_name_list:
-                        message = f'Unknown driver name was specified at index: {driver_name.index(driver)} current name of driver is: {driver}'
+                    result, message = DriverUpdater.__check_parameter_type_is_valid(info._system_name, type(info._driver_name), 'system_name')
+                    if not result:
                         logging.error(message)
-                        return result_run, message
+                        return result, message
 
-                if filename:
 
-                    if type(filename) != list:
-                        message = f'Unknown type of filename was specificed type(filename): {type(filename)}, but must be list[str], if multiply drivers were given'
+                if isinstance(info._driver_name, str):
+
+                    result, message = DriverUpdater.__check_driver_name_is_valid(driver_name=info._driver_name)
+                    if not result:
                         logging.error(message)
-                        return result_run, message
+                        return result, message
+
+                    if info._system_name:
+
+                        result, message = DriverUpdater.__check_system_name_is_valid(system_name=info._system_name)
+                        if not result:
+                            logging.error(message)
+                            return result, message
+
+                elif isinstance(info._driver_name, list):
+
+                    for driver in info._driver_name:
+
+                        result, message = DriverUpdater.__check_driver_name_is_valid(driver_name=driver)
+                        if not result:
+                            message = message + f' at index: {info._driver_name.index(driver)}'
+                            logging.error(message)
+                            return result, message
+
+                    if info._system_name:
+
+                        for os_system in info._system_name:
+
+                            result, message = DriverUpdater.__check_system_name_is_valid(system_name=os_system)
+                            if not result:
+                                message = message + f' at index: {info._system_name.index(os_system)}'
+                                logging.error(message)
+                                return result, message
 
             else:
 
-                message = f'Unknown type of driver name was specified, this library only supports str or list[str], current type is: {type(driver_name)}'
+                message = f'The type of "driver_name" must be a list or str current type is: {type(info._driver_name)}'
                 logging.error(message)
                 return result_run, message
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
         return result_run, message_run
-    
+
     @staticmethod
     def __check_library_is_up_to_date() -> Tuple[bool, str]:
         """Private function for comparing latest version and current version of program
@@ -236,22 +282,22 @@ class DriverUpdater():
             message_run (str)       : Empty string if function passed correctly, non-empty string if error.
 
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
         result_run : bool = False
         message_run : str = ''
+        url : str = str(setting["PyPi"]["urlProjectJson"])
 
         try:
-            
-            url = setting["PyPi"]["urlProjectJson"]
+
             result, message, status_code, json_data = RequestsGetter.get_result_by_request(url=url, is_json=True)
             if not result:
                 logging.error(message)
                 return result, message
 
-            current_version = setting["Program"]["version"].replace('b', '')
+            current_version = str(setting["Program"]["version"]).replace('b', '')
             latest_version = json_data.get('info').get('version')
 
             current_version_tuple = tuple(map(int, (current_version.split("."))))
@@ -265,14 +311,14 @@ class DriverUpdater():
             elif latest_version_tuple == current_version_tuple:
                 message = 'Your selenium-driver-updater library is up to date.'
                 logging.info(message)
-            
+
             else:
                 message = 'Unable to compare the latest version and current version of the library, maybe you are using a beta version.'
                 logging.error(message)
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
@@ -289,7 +335,7 @@ class DriverUpdater():
             message_run (str)       : Empty string if function passed correctly, non-empty string if error.
 
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
@@ -310,21 +356,16 @@ class DriverUpdater():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
         return result_run, message_run
 
     @staticmethod
-    def __check_enviroment_and_variables(path : str, driver_name, enable_library_update_check : bool, filename) -> Tuple[bool, str]:
+    def __check_enviroment_and_variables() -> Tuple[bool, str]:
         """Private function for checking all input parameters and enviroment
 
-        Args:
-            path (str)                          : Specified path which will used for downloading or updating Selenium driver binary. Must be folder path.
-            driver_name (Union[str, list[str]]) : Specified driver name/names which will be downloaded or updated. Like "DriverUpdater.chromedriver" or etc.
-            enable_library_update_check (bool)  : If true, it will enable checking for library update while starting.
-
         Returns:
             Tuple of bool and str
 
@@ -332,7 +373,7 @@ class DriverUpdater():
             message_run (str)       : Empty string if function passed correctly, non-empty string if error.
 
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
 
@@ -345,41 +386,35 @@ class DriverUpdater():
                 logging.error(message)
                 return result, message
 
-            if enable_library_update_check:
+            if info._enable_library_update_check:
 
                 result, message = DriverUpdater.__check_library_is_up_to_date()
                 if not result:
                     logging.error(message)
                     return result, message
 
-            result, message = DriverUpdater.__check_all_input_parameteres(path=path, driver_name=driver_name, filename=filename)
+            result, message = DriverUpdater.__check_all_input_parameteres()
             if not result:
                 logging.error(message)
                 return result, message
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
         return result_run, message_run
-    
+
     @staticmethod
-    def __run_specific_driver(driver_name, **kwargs) -> Tuple[bool, str, str]:
+    def __run_specific_driver(**kwargs) -> Tuple[bool, str, str]:
         """Private function for run download or update for specific driver
 
         Args:
             driver_name (Union[str, list[str]]) : Specified driver name/names which will be downloaded or updated. Like "DriverUpdater.chromedriver" or etc.
-            path (str)                          : Specified path which will used for downloading or updating Selenium driver binary. Must be folder path.
-            upgrade (bool)                      : If true, it will overwrite existing driver in the folder.
-            chmod (bool)                        : If true, it will make chromedriver binary executable.
-            check_driver_is_up_to_date (bool)   : If true, it will check driver version before and after upgrade.
-            info_messages (bool)                : If false, it will disable all info messages.
-            filename (str)                      : Specific name for chromedriver. If given, it will replace name for chromedriver.
-            version (str)                       : Specific version for chromedriver. If given, it will downloads given version.
-            check_browser_is_up_to_date (bool)  : If true, it will check browser version before specific driver update or upgrade.
-            enable_library_update_check (bool)  : If true, it will enable checking for library update while starting.
+            filename (str)                      : Specific name for chromedriver. If given, it will replace name for chromedriver. Defaults to empty string.
+            version (str)                       : Specific version for chromedriver. If given, it will downloads given version. Defaults to empty string.
+            system_name (Union[str, list[str]]) : Specific OS for driver. Defaults to empty string.
 
         Returns:
             Tuple of bool and str
@@ -388,32 +423,32 @@ class DriverUpdater():
             message_run (str)       : Empty string if function passed correctly, non-empty string if error.
 
         Raises:
-            Except: If unexpected error raised. 
+            Except: If unexpected error raised.
 
         """
-        
+
 
         result_run : bool = False
         message_run : str = ''
-
-        path = kwargs.get('path')         
-        upgrade = kwargs.get('upgrade')
-        chmod = kwargs.get('chmod')
-        check_driver_is_up_to_date = kwargs.get('check_driver_is_up_to_date')
-        filename = kwargs.get('filename')
-        version = kwargs.get('version')
-        check_browser_is_up_to_date = kwargs.get('check_browser_is_up_to_date')
-        info_messages = kwargs.get('info_messages')
         driver_path : str = ''
 
         try:
 
+            driver_name = kwargs.get('driver_name', info._driver_name)
+            filename = kwargs.get('filename', info._filename)
+            version = kwargs.get('version', info._version)
+            system_name = kwargs.get('system_name', info._system_name)
+
+            parametres = dict(  path=info._path, upgrade=info._upgrade, chmod=info._chmod,
+                                check_driver_is_up_to_date=info._check_driver_is_up_to_date,
+                                filename=filename, version=version,
+                                check_browser_is_up_to_date=info._check_browser_is_up_to_date,
+                                info_messages=info._info_messages,
+                                system_name=system_name )
+
             if DriverUpdater.chromedriver == driver_name:
 
-                chrome_driver = ChromeDriver(path=path, upgrade=upgrade, chmod=chmod, 
-                                            check_driver_is_up_to_date=check_driver_is_up_to_date, 
-                                            filename=filename, version=version,
-                                            check_browser_is_up_to_date=check_browser_is_up_to_date, info_messages=info_messages)
+                chrome_driver = ChromeDriver(**parametres)
                 result, message, driver_path = chrome_driver.main()
                 if not result:
                     logging.error(message)
@@ -421,10 +456,7 @@ class DriverUpdater():
 
             elif DriverUpdater.geckodriver == driver_name:
 
-                gecko_driver = GeckoDriver(path=path, upgrade=upgrade, chmod=chmod, 
-                                        check_driver_is_up_to_date=check_driver_is_up_to_date, 
-                                        filename=filename, version=version,
-                                        check_browser_is_up_to_date=check_browser_is_up_to_date, info_messages=info_messages)
+                gecko_driver = GeckoDriver(**parametres)
                 result, message, driver_path = gecko_driver.main()
                 if not result:
                     logging.error(message)
@@ -432,10 +464,7 @@ class DriverUpdater():
 
             elif DriverUpdater.operadriver == driver_name:
 
-                opera_driver = OperaDriver(path=path, upgrade=upgrade, chmod=chmod, 
-                                        check_driver_is_up_to_date=check_driver_is_up_to_date, 
-                                        filename=filename, version=version,
-                                        check_browser_is_up_to_date=check_browser_is_up_to_date, info_messages=info_messages)
+                opera_driver = OperaDriver(**parametres)
                 result, message, driver_path = opera_driver.main()
                 if not result:
                     logging.error(message)
@@ -443,10 +472,7 @@ class DriverUpdater():
 
             elif DriverUpdater.edgedriver == driver_name:
 
-                edge_driver = EdgeDriver(path=path, upgrade=upgrade, chmod=chmod, 
-                                    check_driver_is_up_to_date=check_driver_is_up_to_date, 
-                                    filename=filename, version=version,
-                                    check_browser_is_up_to_date=check_browser_is_up_to_date, info_messages=info_messages)
+                edge_driver = EdgeDriver(**parametres)
                 result, message, driver_path = edge_driver.main()
                 if not result:
                     logging.error(message)
@@ -454,8 +480,7 @@ class DriverUpdater():
 
             elif DriverUpdater.chromium_chromedriver == driver_name:
 
-                chromium_chromedriver = ChromiumChromeDriver(check_driver_is_up_to_date=check_driver_is_up_to_date, 
-                                                            check_browser_is_up_to_date=check_browser_is_up_to_date, info_messages=info_messages)
+                chromium_chromedriver = ChromiumChromeDriver(**parametres)
                 result, message, driver_path = chromium_chromedriver.main()
                 if not result:
                     logging.error(message)
@@ -463,9 +488,7 @@ class DriverUpdater():
 
             elif DriverUpdater.phantomjs == driver_name:
 
-                phantomjs = PhantomJS(path=path, upgrade=upgrade, chmod=chmod, 
-                                    check_driver_is_up_to_date=check_driver_is_up_to_date, 
-                                    filename=filename, version=version, info_messages=info_messages)
+                phantomjs = PhantomJS(**parametres)
                 result, message, driver_path = phantomjs.main()
                 if not result:
                     logging.error(message)
@@ -473,8 +496,96 @@ class DriverUpdater():
 
             result_run = True
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {traceback.format_exc()}'
             logging.error(message_run)
 
-        return result_run, message_run, driver_path
\ No newline at end of file
+        return result_run, message_run, driver_path
+
+    @staticmethod
+    def __check_driver_name_is_valid(driver_name):
+        """Private function for checking if specified driver_name is exists and valid
+
+        Returns:
+            Tuple of bool and str
+
+            result_run (bool)       : True if function passed correctly, False otherwise.
+            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
+
+        Raises:
+            Except: If unexpected error raised.
+
+        """
+        result_run : bool = False
+        message_run : str = ''
+
+        try:
+
+            driver_name_check = driver_name in list(vars(DriverUpdater))
+
+            if not driver_name_check:
+                message = f'Unknown driver name was specified current driver_name is: {driver_name}'
+                logging.error(message)
+                return result_run, message
+
+            result_run = True
+
+        except Exception:
+            message_run = f'Unexcepted error: {traceback.format_exc()}'
+            logging.error(message_run)
+
+        return result_run, message_run
+
+    @staticmethod
+    def __check_system_name_is_valid(system_name):
+        """Private function for checking if specified system_name is exists and valid
+
+        Returns:
+            Tuple of bool and str
+
+            result_run (bool)       : True if function passed correctly, False otherwise.
+            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
+
+        Raises:
+            Except: If unexpected error raised.
+
+        """
+        result_run : bool = False
+        message_run : str = ''
+
+        try:
+
+            system_name_check = system_name in [DriverUpdater.__dict__[item] for item in DriverUpdater.__dict__]
+
+            if not system_name_check:
+                message = f'Unknown system name was specified current system_name is: {system_name}'
+                logging.error(message)
+                return result_run, message
+
+            result_run = True
+
+        except Exception:
+            message_run = f'Unexcepted error: {traceback.format_exc()}'
+            logging.error(message_run)
+
+        return result_run, message_run
+
+    @staticmethod
+    def __check_parameter_type_is_valid(parameter, needed_type, parameter_name):
+        result_run : bool = False
+        message_run : str = ''
+
+        try:
+
+            if not isinstance(parameter, needed_type):
+                message = f'The type of {parameter_name} must be a {needed_type} current type is: {type(parameter)}'
+                logging.error(message)
+                return result_run, message
+
+            result_run = True
+
+        except Exception:
+            message_run = f'Unexcepted error: {traceback.format_exc()}'
+            logging.error(message_run)
+
+        return result_run, message_run
